function [sys, x0] = adapt(t,x,u,flag,alpha, init_freq)

% function [sys, x0] = adapt(t,x,u,flag,alpha)
% s-function: frequency adaptation mechanism for AFA
% alpha is the adaptation factor (suggested value:1)
% init_freq is the initial fundamental frequency.

% uses calrl
% the frequency values are in the range of 0..0.5.
% Original algorithm proposed by Ferenc Nagy.

% (c) Gy. Simon, 28-07-1997

Max_L=49;


sample=1;	  % Sample time
ns=0;             % Number of continuous states
nd=4;		  % Number of discrete states: X1 (re, im); fundamental freq, L
ni=2;		  % Number of inputs 
no=1+Max_L+1;	  % Number of outputs: L, frequency vect (padded with zeros)


if  abs(flag)==2


	sample_hit = (rem(t+sample/1e8,sample) < sample/1e6);
	if sample_hit


		old_x1=x(1)+j*x(2);
		new_x1=u(1)+j*u(2);
	
		df=angle(new_x1*conj(old_x1));
	
		old_fund_freq=x(3);
		L=x(4);
		N=2*L+1;
		new_fund_freq = old_fund_freq+alpha*df/2/pi/N;
	
		MinFreq=0.51/Max_L;
		MaxFreq=0.45;
	
		if new_fund_freq > MaxFreq
			new_fund_freq=MaxFreq;
		elseif new_fund_freq <MinFreq
			new_fund_freq = MinFreq;
		end
		new_L = calcl(new_fund_freq);
	
	
		sys=[real(new_x1), imag(new_x1), new_fund_freq, new_L];

	else
		sys = x;
	end
elseif flag == 3
	fund_freq=x(3);
	L=x(4);
	freqs= fund_freq*[0:L];
	sys=[L, freqs, inf*ones(1, Max_L-L)];

elseif flag ==4, 
	sys=ceil(t/sample+sample/1e8)*sample;

elseif flag == 0,
	init_L = calcl(init_freq);
	sys=[ns,nd,no,ni,0,1];
	x0=[1,0,init_freq,init_L];
end

