function [sys, x0] = blsigcon(t,x,u,flag, MaxN, Shape, sample)


% function [sys, x0] = blsigcon(t,x,u,flag, MaxN, Shape, sample)
% S-function generates band-limited signals with the given amplitude, 
% frequency, and shape. Amplitude and frequency are input values 
% rather than parameters. (See BLSIGGEN)
% Freq is between 0 and pi.
%
% Amplitude and frequency are scalar, the signal's shape is determined 
% by the Shape parameter: 'S'- sine, 'T'- triangular, 'Q'- square. 
%
% MaxN determines the maximum number of harmonics (can not be changed 
% in run-time).
% See also BLSIGGEN.

% (c) Gy. Simon, 28-07-1997

N=1; Phase=0;
ns=0;
nd=MaxN;	% actual phase values are stored here
no=1;
ni=2;		% Freq, Ampl



if  abs(flag)==2

	sample_hit = (rem(t+sample/1e8,sample) < sample/1e6);
	if sample_hit 
		Freq=u(1); Ampl=u(2);
		if t>0
		   % initialize the phase for all harmonics 
		   % from the fund freq's phase
		   fundPh=x(1)-t*Freq;
		   x=(1:MaxN)'*(fundPh+t*Freq);
		end
		NLimit=min(floor(pi/Freq), MaxN);
		if strcmp(lower(Shape),'s')	
		   % sine: nothing to do
		elseif strcmp(lower(Shape),'t')	
		   Freq=Freq*[1:MaxN];
		   Freq(2:2:MaxN)=zeros(1,floor(MaxN/2));
		   Ampl=Ampl./([1:NLimit]'.^2);
		   Ampl(2:2:NLimit)=zeros(floor(NLimit/2),1);
		   Ampl(3:4:NLimit)=-Ampl(3:4:NLimit);
		   N=NLimit;
		elseif  strcmp(lower(Shape),'q')	
		   Freq=Freq*[1:MaxN];
		   Freq(2:2:MaxN)=zeros(1,floor(MaxN/2));
		   Ampl=Ampl./([1:NLimit]');
		   Ampl(2:2:NLimit)=zeros(floor(NLimit/2),1);
		   N=NLimit;
		else
		   error(['Band-limited Signal Generator error: ' ...
			'unknown signal shape: ' Shape])
		end

		TooHighFreqs=find(Freq>=pi);
		Ampl(TooHighFreqs)=zeros(size(TooHighFreqs));
		Freq =[Freq(:); zeros(MaxN-length(Freq),1)];
		Ampl =[Ampl(:); zeros(MaxN-length(Ampl),1)];
		Ampl(NLimit+1:MaxN)=zeros(MaxN-NLimit,1);

		x=x(1:MaxN)+Freq*sample;
		y=sum(Ampl.*sin(x));
		sys=[x; y];
	else
		sys = x;
	end
elseif flag == 3
	sys=x(MaxN+1);
elseif flag ==4, 
	sys=ceil(t/sample+sample/1e8)*sample;

elseif flag == 0,
	if N==1; Phase=[1:MaxN]'*Phase; end
	sys=[ns,nd+no,no,ni,0,0]; x0 = [Phase(:); zeros(1+MaxN-length(Phase),1)];
end
