function r=calcrs(ResFreqs, Method);

% function r=calcrs(ResFreqs, Method);
% Calculates the coefficient vector 'r' for the resonator bank.
%
% Vector ResFreqs contains the frequencies of the resonators 
% with non-negative imag part. (DC -> 0, fs/2 -> 0.5)
%
% Method determines the calculation method of the 'r' vector.
% Method is a string, which may be 'FIR', or 'alpha/N', where
% alpha is a number between zero and 1 (e.g. '0.5/N').

% used by resonfa
% the frequency values are in the range of 0..0.5.

% (c) Gy. Simon, 28-07-1997

dc_ix=find((ResFreqs == 0)|(ResFreqs == 0.5));
comp_ix=find((ResFreqs <0.5)& (ResFreqs >0));


N=2*length(comp_ix)+length(dc_ix);
ix=findstr(Method,'/N');

if ~isempty(ix) & (ix>1)  % alpha/N
	alpha=str2num(Method(1:ix-1));
	r=alpha/N;
elseif strcmp(lower(Method), 'fir')
	zz=[exp(j*2*pi*[ResFreqs;-(ResFreqs(comp_ix))])];
	r=ones(length(ResFreqs),1);
	for m=1:length(ResFreqs);
		for n=1:N
		    if n~=m
			r(m)=r(m)/(1-zz(n)/zz(m));
	 	    end
		end
	end
	r(dc_ix)=real(r(dc_ix));

else
	error(['Resonator bank error. Unknown calcr method: ' Method])
end