function [ret,x0,str,ts,xts]=illustr(t,x,u,flag);
%ILLUSTR	is the M-file description of the SIMULINK system named ILLUSTR.
%	The block-diagram can be displayed by typing: ILLUSTR.
%
%	SYS=ILLUSTR(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes ILLUSTR to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling ILLUSTR with a FLAG of zero:
%	[SIZES]=ILLUSTR([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,66,529,289])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'Peak','1.000000',...
		'Peak Range','5.000000',...
		'Freq','0.100000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[70,68,115,102])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','3.000000',...
		'Hgain','100.000000',...
		'Vmax','6.000000',...
		'Hmax','200.000000',...
		'Window',[392,126,640,412])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[180,17,200,43])


%     Subsystem  'LED'.

new_system([sys,'/','LED'])
set_param([sys,'/','LED'],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/','LED/S-function: led'])
set_param([sys,'/','LED/S-function: led'],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/','LED/in_1'])
set_param([sys,'/','LED/in_1'],...
		'position',[35,100,55,120])
add_line([sys,'/','LED'],[60,110;80,110])
set_param([sys,'/','LED'],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:',...
		'Mask Translate','COLOR=@1;sample=@2;')
set_param([sys,'/','LED'],...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[6 1 7]\/1\/')


%     Finished composite block 'LED'.

set_param([sys,'/','LED'],...
		'position',[185,80,205,90])


%     Subsystem  'Counter'.

new_system([sys,'/','Counter'])
set_param([sys,'/','Counter'],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/','Counter/S-function: counter'])
set_param([sys,'/','Counter/S-function: counter'],...
		'function name','counter',...
		'parameters','threshold, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/','Counter/input'])
set_param([sys,'/','Counter/input'],...
		'position',[35,100,55,120])

add_block('built-in/Outport',[sys,'/','Counter/Output'])
set_param([sys,'/','Counter/Output'],...
		'position',[190,100,210,120])
add_line([sys,'/','Counter'],[60,110;80,110])
add_line([sys,'/','Counter'],[145,110;185,110])
set_param([sys,'/','Counter'],...
		'Mask Display','counter',...
		'Mask Type','Counter',...
		'Mask Dialogue','Counter. Indicates the time since input >= threshold|Threshold:|Min update interval:',...
		'Mask Translate','threshold=@1;sample=@2;')
set_param([sys,'/','Counter'],...
		'Mask Help','Counter block.',...
		'Mask Entries','0\/1\/')


%     Finished composite block 'Counter'.

set_param([sys,'/','Counter'],...
		'position',[200,154,235,186])


%     Subsystem  'monitor'.

new_system([sys,'/','monitor'])
set_param([sys,'/','monitor'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','monitor/monitor S-fcn'])
set_param([sys,'/','monitor/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','monitor/in_1'])
set_param([sys,'/','monitor/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','monitor'],[40,90;50,90])
set_param([sys,'/','monitor'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','monitor'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','monitor'],...
		'Mask Entries','10\/')


%     Finished composite block 'monitor'.

set_param([sys,'/','monitor'],...
		'position',[200,114,235,136])

add_block('built-in/Note',[sys,'/',['This demo illustrates the usgae of several new blocks:',13,'monitor, LED, conter']])
set_param([sys,'/',['This demo illustrates the usgae of several new blocks:',13,'monitor, LED, conter']],...
		'position',[360,50,365,55])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'Expr','u[1]==0',...
		'position',[295,159,350,181])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'Expr','u[1]>20',...
		'position',[295,124,350,146])


%     Subsystem  'LED2'.

new_system([sys,'/','LED2'])
set_param([sys,'/','LED2'],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/','LED2/S-function: led'])
set_param([sys,'/','LED2/S-function: led'],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/','LED2/in_1'])
set_param([sys,'/','LED2/in_1'],...
		'position',[35,100,55,120])
add_line([sys,'/','LED2'],[60,110;80,110])
set_param([sys,'/','LED2'],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:',...
		'Mask Translate','COLOR=@1;sample=@2;')
set_param([sys,'/','LED2'],...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[6 1 2]\/1\/')


%     Finished composite block 'LED2'.

set_param([sys,'/','LED2'],...
		'position',[480,155,500,165])


%     Subsystem  'LED1'.

new_system([sys,'/','LED1'])
set_param([sys,'/','LED1'],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/','LED1/S-function: led'])
set_param([sys,'/','LED1/S-function: led'],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/','LED1/in_1'])
set_param([sys,'/','LED1/in_1'],...
		'position',[35,100,55,120])
add_line([sys,'/','LED1'],[60,110;80,110])
set_param([sys,'/','LED1'],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:',...
		'Mask Translate','COLOR=@1;sample=@2;')
set_param([sys,'/','LED1'],...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[6 1 2]\/1\/')


%     Finished composite block 'LED1'.

set_param([sys,'/','LED1'],...
		'position',[480,130,500,140])


%     Subsystem  'Latch'.

new_system([sys,'/','Latch'])
set_param([sys,'/','Latch'],'Location',[102,294,551,460])

add_block('built-in/Inport',[sys,'/','Latch/in_2'])
set_param([sys,'/','Latch/in_2'],...
		'Port','2',...
		'position',[50,65,70,85])

add_block('built-in/Inport',[sys,'/','Latch/in_1'])
set_param([sys,'/','Latch/in_1'],...
		'position',[20,50,40,70])

add_block('built-in/Mux',[sys,'/','Latch/Mux'])
set_param([sys,'/','Latch/Mux'],...
		'inputs','3',...
		'position',[135,59,165,91])

add_block('built-in/Outport',[sys,'/','Latch/out_1'])
set_param([sys,'/','Latch/out_1'],...
		'position',[355,55,375,75])

add_block('built-in/Outport',[sys,'/','Latch/out_2'])
set_param([sys,'/','Latch/out_2'],...
		'Port','2',...
		'position',[395,70,415,90])

add_block('built-in/Transport Delay',[sys,'/','Latch/Transport Delay'])
set_param([sys,'/','Latch/Transport Delay'],...
		'orientation',2,...
		'Initial Input','ini',...
		'position',[250,120,295,150])

add_block('built-in/Combinatorial Logic',[sys,'/','Latch/Logic'])
set_param([sys,'/','Latch/Logic'],...
		'Truth Table','[0 1;1 0;0 1;0 1;1 0;1 0;0 0;0 0]',...
		'position',[195,55,250,95])

add_block('built-in/Demux',[sys,'/','Latch/Demux'])
set_param([sys,'/','Latch/Demux'],...
		'outputs','2',...
		'position',[275,55,315,90])

add_block('built-in/Fcn',[sys,'/','Latch/Fcn'])
set_param([sys,'/','Latch/Fcn'],...
		'orientation',2,...
		'Expr','u[1]>.2',...
		'position',[170,123,205,147])
add_line([sys,'/','Latch'],[320,80;390,80])
add_line([sys,'/','Latch'],[255,75;270,75])
add_line([sys,'/','Latch'],[170,75;190,75])
add_line([sys,'/','Latch'],[45,60;105,60;105,65;130,65])
add_line([sys,'/','Latch'],[75,75;130,75])
add_line([sys,'/','Latch'],[245,135;210,135])
add_line([sys,'/','Latch'],[165,135;110,135;110,85;130,85])
add_line([sys,'/','Latch'],[320,65;350,65])
add_line([sys,'/','Latch'],[335,65;335,135;300,135])
set_param([sys,'/','Latch'],...
		'Mask Display','S  1\n\nR  0',...
		'Mask Type','Latch',...
		'Mask Dialogue','Latch|Initial State for Output "1":',...
		'Mask Translate','ini=(@1~=0);')
set_param([sys,'/','Latch'],...
		'Mask Help','Latches the S input.  When S (set) is one, the uncomplemented output (1) becomes one.  The output remains one until the R (reset) input becomes one, forcing the output to zero.  If both R and S are one, the latch will be in an undefined state.')
set_param([sys,'/','Latch'],...
		'Mask Entries','0\/')


%     Finished composite block 'Latch'.

set_param([sys,'/','Latch'],...
		'position',[395,122,430,173])
add_line(sys,[120,85;180,85])
add_line(sys,[120,85;140,85;140,30;175,30])
add_line(sys,[120,85;150,85;150,170;195,170])
add_line(sys,[435,135;475,135])
add_line(sys,[435,160;475,160])
add_line(sys,[355,135;390,135])
add_line(sys,[355,170;365,170;365,160;390,160])
add_line(sys,[240,170;290,170])
add_line(sys,[150,125;195,125])
add_line(sys,[260,170;260,135;290,135])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
