function [ret,x0,str,ts,xts]=demotest(t,x,u,flag);
%DEMOTEST	is the M-file description of the SIMULINK system named DEMOTEST.
%	The block-diagram can be displayed by typing: DEMOTEST.
%
%	SYS=DEMOTEST(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DEMOTEST to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DEMOTEST with a FLAG of zero:
%	[SIZES]=DEMOTEST([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[490,136,990,436])
     open_system(sys)
end;
set_param(sys,'BackGround',7)
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');


%     Subsystem  ['Auto-Scale',13,'Graph'].

new_system([sys,'/',['Auto-Scale',13,'Graph']])
set_param([sys,'/',['Auto-Scale',13,'Graph']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Auto-Scale',13,'Graph']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/1\/')


%     Finished composite block ['Auto-Scale',13,'Graph'].

set_param([sys,'/',['Auto-Scale',13,'Graph']],...
		'position',[390,75,420,115])

add_block('built-in/S-Function',[sys,'/','S-function'])
set_param([sys,'/','S-function'],...
		'function name','sltest',...
		'Mask Display','',...
		'Mask Type','demotype',...
		'Mask Dialogue','Name | var1:',...
		'Mask Translate','first=@1',...
		'Mask Help','help me !',...
		'Mask Entries','128\/')
set_param([sys,'/','S-function'],...
		'position',[240,70,290,120])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[165,81,200,114])

add_block('built-in/Sine Wave',[sys,'/','Sine wave'])
set_param([sys,'/','Sine wave'],...
		'frequency','.1',...
		'position',[90,125,105,145])

add_block('built-in/S-Function',[sys,'/',['S-function block ',13,'which calls M-file']])
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'function name','sfunpsd',...
		'parameters','fftpts,npts,HowOften,offset,ts,0')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Display','plot(0,0,100,100,[14,91,91,14,14],[86,86,40,40,86],[85,82,80,79,75,67,63,60,57,53,41,36,33,27,24],[49,50,53,50,49,51,54,66,54,50,50,52,81,51,49])')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Type','Spectrum analayser.')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Dialogue','Spectrum anlayser using graph window.|Length of buffer:|Number of points for fft:|Plot after how many points:|Sample time:')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Translate','npts=@1; fftpts=@2; HowOften=@3; ts=@4(1); if length(@4) > 1, offset = @4(2), else, offset = 0; end')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Help','This block when hooked to the output of a system displays the frequency content of the buffer in the graph window. For more information, see the M-file sfunpsd.')
set_param([sys,'/',['S-function block ',13,'which calls M-file']],...
		'Mask Entries','128\/512\/64\/0.1\/',...
		'position',[255,196,305,234])
add_line(sys,[295,95;385,95])
add_line(sys,[205,100;215,100;215,95;235,95])
add_line(sys,[110,135;160,105;135,90;160,90])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
