function [ret,x0,str,ts,xts]=fmdemo(t,x,u,flag);
%FMDEMO	is the M-file description of the SIMULINK system named FMDEMO.
%	The block-diagram can be displayed by typing: FMDEMO.
%
%	SYS=FMDEMO(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes FMDEMO to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling FMDEMO with a FLAG of zero:
%	[SIZES]=FMDEMO([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[33,70,408,231])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','3.000000',...
		'Hgain','1000.000000',...
		'Vmax','6.000000',...
		'Hmax','2000.000000',...
		'Window',[312,31,640,383])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[305,47,325,73])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'position',[160,17,180,53])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator1']])
set_param([sys,'/',['Signal',13,'generator1']],...
		'Peak','0.300000',...
		'Peak Range','5.000000',...
		'Freq','0.050000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[70,8,115,42])

add_block('built-in/Constant',[sys,'/','Constant:Ampl'])
set_param([sys,'/','Constant:Ampl'],...
		'Value','0.5',...
		'position',[80,115,100,135])

add_block('built-in/Constant',[sys,'/','Constant:Freq1'])
set_param([sys,'/','Constant:Freq1'],...
		'Value','.4',...
		'position',[80,65,100,85])


%     Subsystem  ['Controlled Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['Controlled Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],'Location',[4,61,318,253])

add_block('built-in/Outport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']],...
		'position',[215,60,235,80])

add_block('built-in/S-Function',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']],...
		'function name','blsigcon',...
		'parameters',' MaxN, Shape, sample',...
		'position',[125,59,185,81])

add_block('built-in/Mux',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']],...
		'inputs','2',...
		'position',[55,51,90,84])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']],...
		'Port','2',...
		'position',[15,90,35,110])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[190,70;210,70])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[95,70;120,70])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,35;50,60])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,100;50,75])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Type','Controlled Band-limited signal generator')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Controlled Band Limited Signal Generator|Max number of harmonics:|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Translate','MaxN=@1; Shape=@2; sample=@3;',...
		'Mask Help','Band limited Signal Generator. Frequency: input 1;  Amplitude: input 2. ')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Entries','15\/''S''\/1\/')


%     Finished composite block ['Controlled Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'position',[215,41,260,79])

add_block('built-in/Note',[sys,'/','FM demo with Controlled Band Limited Signal Generator'])
set_param([sys,'/','FM demo with Controlled Band Limited Signal Generator'],...
		'position',[240,140,245,145])
add_line(sys,[265,60;300,60])
add_line(sys,[105,125;150,125;150,70;210,70])
add_line(sys,[120,25;155,25])
add_line(sys,[105,75;155,45])
add_line(sys,[185,35;190,35;190,50;210,50])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
