function [ret,x0,str,ts,xts]=resdemo2(t,x,u,flag);
%RESDEMO2	is the M-file description of the SIMULINK system named RESDEMO2.
%	The block-diagram can be displayed by typing: RESDEMO2.
%
%	SYS=RESDEMO2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RESDEMO2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RESDEMO2 with a FLAG of zero:
%	[SIZES]=RESDEMO2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[28,101,572,388])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');

add_block('built-in/Note',[sys,'/','y'])
set_param([sys,'/','y'],...
		'position',[350,105,355,110])

add_block('built-in/Note',[sys,'/','e'])
set_param([sys,'/','e'],...
		'position',[235,110,240,115])

add_block('built-in/Note',[sys,'/','Transfer functions of the resonator bank'])
set_param([sys,'/','Transfer functions of the resonator bank'],...
		'Font Name','Times New Roman',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[230,5,235,10])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','-+',...
		'position',[205,117,225,153])


%     Subsystem  ['Resonator ',13,'bank'].

new_system([sys,'/',['Resonator ',13,'bank']])
set_param([sys,'/',['Resonator ',13,'bank']],'Location',[4,42,618,417])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/input_signal']])
set_param([sys,'/',['Resonator ',13,'bank/input_signal']],...
		'position',[30,75,50,95])

add_block('built-in/S-Function',[sys,'/',['Resonator ',13,'bank/S-function: RFA']])
set_param([sys,'/',['Resonator ',13,'bank/S-function: RFA']],...
		'function name','resonfa',...
		'parameters',' CalcR',...
		'position',[230,70,280,120])

add_block('built-in/Mux',[sys,'/',['Resonator ',13,'bank/Mux']])
set_param([sys,'/',['Resonator ',13,'bank/Mux']],...
		'inputs','2',...
		'position',[160,76,190,109])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select y']])
set_param([sys,'/',['Resonator ',13,'bank/select y']],...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[330,15,380,45])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re']])
set_param([sys,'/',['Resonator ',13,'bank/select Re']],...
		'MATLAB Fcn','u(2:51)',...
		'Output Width','50',...
		'position',[330,80,380,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im']])
set_param([sys,'/',['Resonator ',13,'bank/select Im']],...
		'MATLAB Fcn','u(52:101)',...
		'Output Width','50',...
		'position',[335,145,385,175])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Re X1']],...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,210,385,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Im X1']],...
		'MATLAB Fcn','u(53)',...
		'Output Width','1',...
		'position',[335,275,385,305])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/output_signal_(y)']])
set_param([sys,'/',['Resonator ',13,'bank/output_signal_(y)']],...
		'position',[425,20,445,40])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X)']],...
		'Port','3',...
		'position',[425,150,445,170])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X)']],...
		'Port','2',...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X1)']],...
		'Port','4',...
		'position',[425,215,445,235])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X1)']],...
		'Port','5',...
		'position',[420,280,440,300])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/MATLAB Fcn']])
set_param([sys,'/',['Resonator ',13,'bank/MATLAB Fcn']],...
		'MATLAB Fcn','[u(:); inf*ones(50-length(u),1)]',...
		'Output Width','50',...
		'position',[75,125,125,155])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/FreqVector']])
set_param([sys,'/',['Resonator ',13,'bank/FreqVector']],...
		'Port','2',...
		'position',[30,130,50,150])
add_line([sys,'/',['Resonator ',13,'bank']],[130,140;135,140;135,100;155,100])
add_line([sys,'/',['Resonator ',13,'bank']],[55,140;70,140])
add_line([sys,'/',['Resonator ',13,'bank']],[285,95;325,95])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;315,160;330,160])
add_line([sys,'/',['Resonator ',13,'bank']],[315,160;315,225;330,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,225;315,290;330,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,290;415,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,225;420,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;325,30])
add_line([sys,'/',['Resonator ',13,'bank']],[390,160;420,160])
add_line([sys,'/',['Resonator ',13,'bank']],[385,30;420,30])
add_line([sys,'/',['Resonator ',13,'bank']],[385,95;420,95])
add_line([sys,'/',['Resonator ',13,'bank']],[55,85;155,85])
add_line([sys,'/',['Resonator ',13,'bank']],[195,95;225,95])
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Display','Resonator\nBank',...
		'Mask Type','Resonator bank',...
		'Mask Dialogue','Resonator bank |Calculation method of ''r'' (''alpha/N'', 0<apha<2; or ''FIR'')')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Translate','CalcR=@1;')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Help','Resonator bank structure. Input1: e, Input2: frequency values in rad/s. Output1: y, Output2: ReX, Output3: ImX. [Output4: ReX(1), Output5: ImX(1), for convenience only]')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Entries','''1/N''\/')


%     Finished composite block ['Resonator ',13,'bank'].

set_param([sys,'/',['Resonator ',13,'bank']],...
		'Drop Shadow',4,...
		'position',[250,116,320,194])


%     Subsystem  ['Spectrum Analyzer',13,'(revised)'].

new_system([sys,'/',['Spectrum Analyzer',13,'(revised)']])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],'Location',[4,42,375,227])

add_block('built-in/Inport',[sys,'/',['Spectrum Analyzer',13,'(revised)/system input']])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)/system input']],...
		'position',[55,30,75,50])

add_block('built-in/S-Function',[sys,'/',['Spectrum Analyzer',13,'(revised)/S-function block',13,'which calls M-file']])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)/S-function block',13,'which calls M-file']],...
		'function name','sfuntf1',...
		'parameters','fftpts,npts,HowOften,offset,ts,0',...
		'position',[250,72,295,108])

add_block('built-in/Inport',[sys,'/',['Spectrum Analyzer',13,'(revised)/system output']])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)/system output']],...
		'Port','2',...
		'position',[55,110,75,130])

add_block('built-in/Mux',[sys,'/',['Spectrum Analyzer',13,'(revised)/Mux']])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)/Mux']],...
		'inputs','2',...
		'position',[145,71,175,104])
add_line([sys,'/',['Spectrum Analyzer',13,'(revised)']],[180,90;245,90])
add_line([sys,'/',['Spectrum Analyzer',13,'(revised)']],[80,40;110,40;110,80;140,80])
add_line([sys,'/',['Spectrum Analyzer',13,'(revised)']],[80,120;110,120;110,95;140,95])
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Mask Display','plot(0,0,100,100,[11,93,93,11,11],[90,90,40,40,90],[90,80,72,64,55,45,41,36,20],[50,50,52,59,67,75,78,80,80])',...
		'Mask Type','Spectrum analyzer.')
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Mask Dialogue','Spectrum analyser using graph window.\nHook input 1 to system input.\nHook input 2 to system output.|Length of buffer:|Number of points for fft:|Plot after how many points:|Sample time:')
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Mask Translate','npts=@1; fftpts=@2; HowOften=@3; ts=@4(1); if length(@4) > 1, offset = @4(2), else, offset = 0; end')
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Mask Help','Hook the system''s input to the first port of this block and the system''s output to second port. Results are displayed as the frequency response of this system. Use signals with high harmonic content for best results. ')
set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Mask Entries','1024\/1024\/64\/1\/')


%     Finished composite block ['Spectrum Analyzer',13,'(revised)'].

set_param([sys,'/',['Spectrum Analyzer',13,'(revised)']],...
		'Drop Shadow',4,...
		'position',[440,70,470,110])

add_block('built-in/Step Fcn',[sys,'/','Step input1'])
set_param([sys,'/','Step input1'],...
		'Time','4',...
		'position',[45,155,65,175])

add_block('built-in/Step Fcn',[sys,'/','Step input'])
set_param([sys,'/','Step input'],...
		'Time','3',...
		'position',[45,115,65,135])

add_block('built-in/Sum',[sys,'/','dirac delta'])
set_param([sys,'/','dirac delta'],...
		'inputs','+-',...
		'position',[105,127,125,163])

add_block('built-in/Constant',[sys,'/','freq values'])
set_param([sys,'/','freq values'],...
		'Value','[1/16*[0 1 2 3 4 5 6 7 8]]',...
		'position',[35,202,195,228])

add_block('built-in/Note',[sys,'/','input'])
set_param([sys,'/','input'],...
		'position',[415,60,420,65])

add_block('built-in/Note',[sys,'/','output'])
set_param([sys,'/','output'],...
		'position',[415,80,420,85])

add_block('built-in/Note',[sys,'/','x'])
set_param([sys,'/','x'],...
		'position',[180,125,185,130])


%     Subsystem  'Help'.

new_system([sys,'/','Help'])
set_param([sys,'/','Help'],'Location',[4,88,628,381])

add_block('built-in/Note',[sys,'/',['Help/This system illustrates the properties of the transfer functions of the resonator bank',13,'using different settings.',13,'']])
set_param([sys,'/',['Help/This system illustrates the properties of the transfer functions of the resonator bank',13,'using different settings.',13,'']],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[320,5,325,10])

add_block('built-in/Note',[sys,'/',['Help/I.',13,'The default setting provides an equally spaced resonator set (N=16), and CalcR=''1//N''.',13,'In this case the system has finite impulse reponse.',13,'See the transfer function from the input (x) to the output (y). Verify the theoretical result.']])
set_param([sys,'/',['Help/I.',13,'The default setting provides an equally spaced resonator set (N=16), and CalcR=''1//N''.',13,'In this case the system has finite impulse reponse.',13,'See the transfer function from the input (x) to the output (y). Verify the theoretical result.']],...
		'ForeGround',7)
set_param([sys,'/',['Help/I.',13,'The default setting provides an equally spaced resonator set (N=16), and CalcR=''1//N''.',13,'In this case the system has finite impulse reponse.',13,'See the transfer function from the input (x) to the output (y). Verify the theoretical result.']],...
		'BackGround',7)
set_param([sys,'/',['Help/I.',13,'The default setting provides an equally spaced resonator set (N=16), and CalcR=''1//N''.',13,'In this case the system has finite impulse reponse.',13,'See the transfer function from the input (x) to the output (y). Verify the theoretical result.']],...
		'position',[325,35,330,40])

add_block('built-in/Note',[sys,'/','Help/See also the transfer function from the input to one of the state variables (e.g. X1)'])
set_param([sys,'/','Help/See also the transfer function from the input to one of the state variables (e.g. X1)'],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[320,80,325,85])

add_block('built-in/Note',[sys,'/',['Help/Notes: 1. Since the non-DC resonators are complex conjugate pairs, the output ',13,'of a resonator pair can be computes as 2 times the real part.',13,'2. All the state variables are mixed down to DC, thus the unity gain appears always at DC.']])
set_param([sys,'/',['Help/Notes: 1. Since the non-DC resonators are complex conjugate pairs, the output ',13,'of a resonator pair can be computes as 2 times the real part.',13,'2. All the state variables are mixed down to DC, thus the unity gain appears always at DC.']],...
		'ForeGround',7)
set_param([sys,'/',['Help/Notes: 1. Since the non-DC resonators are complex conjugate pairs, the output ',13,'of a resonator pair can be computes as 2 times the real part.',13,'2. All the state variables are mixed down to DC, thus the unity gain appears always at DC.']],...
		'BackGround',7)
set_param([sys,'/',['Help/Notes: 1. Since the non-DC resonators are complex conjugate pairs, the output ',13,'of a resonator pair can be computes as 2 times the real part.',13,'2. All the state variables are mixed down to DC, thus the unity gain appears always at DC.']],...
		'position',[320,95,325,100])

add_block('built-in/Note',[sys,'/','Help/Verify the theoretical results.'])
set_param([sys,'/','Help/Verify the theoretical results.'],...
		'ForeGround',7,...
		'BackGround',7,...
		'position',[325,130,330,135])

add_block('built-in/Note',[sys,'/',['Help/II.',13,'Now create a non-equally spaced case by deleting some of the resonators! (E.g. f=1//16*[0:6])',13,'See the transfer functions as in I.',13,'']])
set_param([sys,'/',['Help/II.',13,'Now create a non-equally spaced case by deleting some of the resonators! (E.g. f=1//16*[0:6])',13,'See the transfer functions as in I.',13,'']],...
		'ForeGround',7,...
		'BackGround',7)
set_param([sys,'/',['Help/II.',13,'Now create a non-equally spaced case by deleting some of the resonators! (E.g. f=1//16*[0:6])',13,'See the transfer functions as in I.',13,'']],...
		'position',[320,150,325,155])

add_block('built-in/Note',[sys,'/',['Help/III.',13,'Try different settings of CalcR.',13,'In the equally spaced case try 0.2//N, 1//N, 1.5//N.',13,'In the non-equally spaced case try 1//N, and the FIR setting.',13,'What is the drawback of the latter case ? ']])
set_param([sys,'/',['Help/III.',13,'Try different settings of CalcR.',13,'In the equally spaced case try 0.2//N, 1//N, 1.5//N.',13,'In the non-equally spaced case try 1//N, and the FIR setting.',13,'What is the drawback of the latter case ? ']],...
		'ForeGround',7)
set_param([sys,'/',['Help/III.',13,'Try different settings of CalcR.',13,'In the equally spaced case try 0.2//N, 1//N, 1.5//N.',13,'In the non-equally spaced case try 1//N, and the FIR setting.',13,'What is the drawback of the latter case ? ']],...
		'BackGround',7)
set_param([sys,'/',['Help/III.',13,'Try different settings of CalcR.',13,'In the equally spaced case try 0.2//N, 1//N, 1.5//N.',13,'In the non-equally spaced case try 1//N, and the FIR setting.',13,'What is the drawback of the latter case ? ']],...
		'position',[320,190,325,195])

add_block('built-in/Note',[sys,'/',['Help/What is the drawback of the latter case ? ',13,'Verify it with an experiment: Let the input be a noise generator, and see the output noise level on a scope.']])
set_param([sys,'/',['Help/What is the drawback of the latter case ? ',13,'Verify it with an experiment: Let the input be a noise generator, and see the output noise level on a scope.']],...
		'ForeGround',7,...
		'BackGround',7)
set_param([sys,'/',['Help/What is the drawback of the latter case ? ',13,'Verify it with an experiment: Let the input be a noise generator, and see the output noise level on a scope.']],...
		'position',[325,250,330,255])
set_param([sys,'/','Help'],...
		'Mask Display','?')


%     Finished composite block 'Help'.

set_param([sys,'/','Help'],...
		'BackGround',7,...
		'Drop Shadow',4,...
		'position',[425,164,455,186])
add_line(sys,[325,125;340,125;340,105;175,105;175,125;200,125])
add_line(sys,[230,135;245,135])
add_line(sys,[200,215;245,175])
add_line(sys,[130,145;200,145])
add_line(sys,[70,125;80,125;80,135;100,135])
add_line(sys,[70,165;80,165;80,155;100,155])
add_line(sys,[150,145;150,80;435,80])
add_line(sys,[325,125;365,125;365,100;435,100])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
