function [ret,x0,str,ts,xts]=resdemo5(t,x,u,flag);
%RESDEMO5	is the M-file description of the SIMULINK system named RESDEMO5.
%	The block-diagram can be displayed by typing: RESDEMO5.
%
%	SYS=RESDEMO5(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RESDEMO5 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RESDEMO5 with a FLAG of zero:
%	[SIZES]=RESDEMO5([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,126,601,429])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');

add_block('built-in/Note',[sys,'/','y'])
set_param([sys,'/','y'],...
		'position',[395,105,400,110])

add_block('built-in/Note',[sys,'/','e'])
set_param([sys,'/','e'],...
		'position',[280,110,285,115])

add_block('built-in/Note',[sys,'/','AM demodulation using resonator-based FA'])
set_param([sys,'/','AM demodulation using resonator-based FA'],...
		'Font Name','Times New Roman',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[275,5,280,10])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','-+',...
		'position',[240,117,260,153])

add_block('built-in/Constant',[sys,'/','freq values'])
set_param([sys,'/','freq values'],...
		'Value','[0:8]/16',...
		'position',[200,224,245,246])

add_block('built-in/Constant',[sys,'/','Constant:Freq'])
set_param([sys,'/','Constant:Freq'],...
		'Value','2*pi/16',...
		'position',[60,125,95,145])


%     Subsystem  ['Controlled Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['Controlled Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],'Location',[4,61,318,253])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']],...
		'position',[15,25,35,45])

add_block('built-in/Mux',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']],...
		'inputs','2',...
		'position',[55,51,90,84])

add_block('built-in/S-Function',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']],...
		'function name','blsigcon',...
		'parameters',' MaxN, Shape, sample',...
		'position',[125,59,185,81])

add_block('built-in/Outport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']],...
		'position',[215,60,235,80])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,100;50,75])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,35;50,60])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[95,70;120,70])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[190,70;210,70])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Type','Controlled Band-limited signal generator')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Controlled Band Limited Signal Generator|Max number of harmonics:|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Translate','MaxN=@1; Shape=@2; sample=@3;',...
		'Mask Help','Band limited Signal Generator. Frequency: input 1;  Amplitude: input 2. ')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Entries','15\/''s''\/1\/')


%     Finished composite block ['Controlled Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'position',[160,126,205,164])


%     Subsystem  ['Resonator ',13,'bank'].

new_system([sys,'/',['Resonator ',13,'bank']])
set_param([sys,'/',['Resonator ',13,'bank']],'Location',[4,42,618,417])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/input_signal']])
set_param([sys,'/',['Resonator ',13,'bank/input_signal']],...
		'position',[30,75,50,95])

add_block('built-in/S-Function',[sys,'/',['Resonator ',13,'bank/S-function: RFA']])
set_param([sys,'/',['Resonator ',13,'bank/S-function: RFA']],...
		'function name','resonfa',...
		'parameters',' CalcR',...
		'position',[230,70,280,120])

add_block('built-in/Mux',[sys,'/',['Resonator ',13,'bank/Mux']])
set_param([sys,'/',['Resonator ',13,'bank/Mux']],...
		'inputs','2',...
		'position',[160,76,190,109])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select y']])
set_param([sys,'/',['Resonator ',13,'bank/select y']],...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[330,15,380,45])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re']])
set_param([sys,'/',['Resonator ',13,'bank/select Re']],...
		'MATLAB Fcn','u(2:51)',...
		'Output Width','50',...
		'position',[330,80,380,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im']])
set_param([sys,'/',['Resonator ',13,'bank/select Im']],...
		'MATLAB Fcn','u(52:101)',...
		'Output Width','50',...
		'position',[335,145,385,175])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Re X1']],...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,210,385,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Im X1']],...
		'MATLAB Fcn','u(53)',...
		'Output Width','1',...
		'position',[335,275,385,305])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/output_signal_(y)']])
set_param([sys,'/',['Resonator ',13,'bank/output_signal_(y)']],...
		'position',[425,20,445,40])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X)']],...
		'Port','3',...
		'position',[425,150,445,170])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X)']],...
		'Port','2',...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X1)']],...
		'Port','4',...
		'position',[425,215,445,235])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X1)']],...
		'Port','5',...
		'position',[420,280,440,300])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/MATLAB Fcn']])
set_param([sys,'/',['Resonator ',13,'bank/MATLAB Fcn']],...
		'MATLAB Fcn','[u(:); inf*ones(50-length(u),1)]',...
		'Output Width','50',...
		'position',[75,125,125,155])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/FreqVector']])
set_param([sys,'/',['Resonator ',13,'bank/FreqVector']],...
		'Port','2',...
		'position',[30,130,50,150])
add_line([sys,'/',['Resonator ',13,'bank']],[130,140;135,140;135,100;155,100])
add_line([sys,'/',['Resonator ',13,'bank']],[55,140;70,140])
add_line([sys,'/',['Resonator ',13,'bank']],[285,95;325,95])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;315,160;330,160])
add_line([sys,'/',['Resonator ',13,'bank']],[315,160;315,225;330,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,225;315,290;330,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,290;415,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,225;420,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;325,30])
add_line([sys,'/',['Resonator ',13,'bank']],[390,160;420,160])
add_line([sys,'/',['Resonator ',13,'bank']],[385,30;420,30])
add_line([sys,'/',['Resonator ',13,'bank']],[385,95;420,95])
add_line([sys,'/',['Resonator ',13,'bank']],[55,85;155,85])
add_line([sys,'/',['Resonator ',13,'bank']],[195,95;225,95])
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Display','Resonator\nBank',...
		'Mask Type','Resonator bank',...
		'Mask Dialogue','Resonator bank |Calculation method of ''r'' (''alpha/N'', 0<apha<2; or ''FIR'')')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Translate','CalcR=@1;')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Help','Resonator bank structure. Input1: e, Input2: frequency values in rad/s. Output1: y, Output2: ReX, Output3: ImX. [Output4: ReX(1), Output5: ImX(1), for convenience only]')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Entries','''1/N''\/')


%     Finished composite block ['Resonator ',13,'bank'].

set_param([sys,'/',['Resonator ',13,'bank']],...
		'Drop Shadow',4,...
		'position',[295,116,365,194])

add_block('built-in/Note',[sys,'/',['frequency',13,'vector']])
set_param([sys,'/',['frequency',13,'vector']],...
		'position',[270,185,275,190])

add_block('built-in/Signal Generator',[sys,'/',['Signal generator: ',13,'AM modulator']])
set_param([sys,'/',['Signal generator: ',13,'AM modulator']],...
		'Peak','0.200000',...
		'Peak Range','5.000000',...
		'Freq','0.050000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[35,173,80,207])

add_block('built-in/Constant',[sys,'/',['Constant:',13,'amplitude bias']])
set_param([sys,'/',['Constant:',13,'amplitude bias']],...
		'Value','0.8',...
		'position',[40,250,75,270])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'position',[110,182,130,218])


%     Subsystem  ['Complex',13,'Abs'].

new_system([sys,'/',['Complex',13,'Abs']])
set_param([sys,'/',['Complex',13,'Abs']],'Location',[154,254,709,464])

add_block('built-in/Sum',[sys,'/',['Complex',13,'Abs/Sum1']])
set_param([sys,'/',['Complex',13,'Abs/Sum1']],...
		'position',[325,110,345,130])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product1']])
set_param([sys,'/',['Complex',13,'Abs/Product1']],...
		'position',[265,140,290,160])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product']])
set_param([sys,'/',['Complex',13,'Abs/Product']],...
		'position',[265,85,290,105])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_1']])
set_param([sys,'/',['Complex',13,'Abs/in_1']],...
		'position',[155,80,175,100])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_2']])
set_param([sys,'/',['Complex',13,'Abs/in_2']],...
		'Port','2',...
		'position',[155,135,175,155])

add_block('built-in/Outport',[sys,'/',['Complex',13,'Abs/out_1']])
set_param([sys,'/',['Complex',13,'Abs/out_1']],...
		'position',[445,110,465,130])

add_block('built-in/MATLAB Fcn',[sys,'/',['Complex',13,'Abs/MATLAB Fcn']])
set_param([sys,'/',['Complex',13,'Abs/MATLAB Fcn']],...
		'MATLAB Fcn','sqrt',...
		'position',[370,105,420,135])
add_line([sys,'/',['Complex',13,'Abs']],[350,120;365,120])
add_line([sys,'/',['Complex',13,'Abs']],[295,150;300,150;300,125;320,125])
add_line([sys,'/',['Complex',13,'Abs']],[295,95;300,95;300,115;320,115])
add_line([sys,'/',['Complex',13,'Abs']],[180,145;260,145])
add_line([sys,'/',['Complex',13,'Abs']],[250,145;225,145;225,155;260,155])
add_line([sys,'/',['Complex',13,'Abs']],[180,90;260,90])
add_line([sys,'/',['Complex',13,'Abs']],[240,90;220,90;220,100;260,100])
add_line([sys,'/',['Complex',13,'Abs']],[425,120;440,120])
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Display','[Re, Im] \n->Abs',...
		'Mask Type','Complex Abs',...
		'Mask Dialogue','Absulute value of  a complex number')
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Help','Converts complex input (Real and Imag components) into absulute value. ')


%     Finished composite block ['Complex',13,'Abs'].

set_param([sys,'/',['Complex',13,'Abs']],...
		'position',[405,130,460,165])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[480,61,515,94])


%     Subsystem  ['Auto-Scale',13,'Graph2'].

new_system([sys,'/',['Auto-Scale',13,'Graph2']])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph2/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Auto-Scale',13,'Graph2']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Entries','100\/-1.1\/1.1\/100\/''r-/g-/c-/y-/w-/m-/b-''\/1\/')


%     Finished composite block ['Auto-Scale',13,'Graph2'].

set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'position',[550,60,580,100])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','0.5',...
		'position',[345,59,375,81])


%     Subsystem  'Help'.

new_system([sys,'/','Help'])
set_param([sys,'/','Help'],'Location',[24,104,420,278])

add_block('built-in/Note',[sys,'/','Help/This system illustrates the AM demodulation using resonator bank.'])
set_param([sys,'/','Help/This system illustrates the AM demodulation using resonator bank.'],...
		'position',[210,15,215,20])

add_block('built-in/Note',[sys,'/',['Help/The red signal is the modulator signal (devided by two), the cyan is the ',13,'fundamental frequency''s amplitude estimator.']])
set_param([sys,'/',['Help/The red signal is the modulator signal (devided by two), the cyan is the ',13,'fundamental frequency''s amplitude estimator.']],...
		'position',[210,50,215,55])

add_block('built-in/Note',[sys,'/',['Help/The system''s transient is clearly visible.',13,'You can try other modulator signals with different frequencies, ',13,'and also different carrier signals.']])
set_param([sys,'/',['Help/The system''s transient is clearly visible.',13,'You can try other modulator signals with different frequencies, ',13,'and also different carrier signals.']],...
		'position',[210,100,215,105])
set_param([sys,'/','Help'],...
		'Mask Display','?')


%     Finished composite block 'Help'.

set_param([sys,'/','Help'],...
		'BackGround',7,...
		'Drop Shadow',4,...
		'position',[450,215,480,237])
add_line(sys,[370,140;400,140])
add_line(sys,[370,155;400,155])
add_line(sys,[370,125;385,125;385,105;220,105;220,125;235,125])
add_line(sys,[265,135;290,135])
add_line(sys,[250,235;290,175])
add_line(sys,[100,135;155,135])
add_line(sys,[465,150;475,85])
add_line(sys,[520,80;545,80])
add_line(sys,[210,145;235,145])
add_line(sys,[380,70;475,70])
add_line(sys,[85,190;105,190])
add_line(sys,[80,260;95,260;105,210])
add_line(sys,[135,200;140,200;140,155;155,155])
add_line(sys,[140,155;140,70;340,70])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
