function [ret,x0,str,ts,xts]=resdemo7(t,x,u,flag);
%RESDEMO7	is the M-file description of the SIMULINK system named RESDEMO7.
%	The block-diagram can be displayed by typing: RESDEMO7.
%
%	SYS=RESDEMO7(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RESDEMO7 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RESDEMO7 with a FLAG of zero:
%	[SIZES]=RESDEMO7([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[28,50,608,449])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignSampleTimeColors','on');


%     Subsystem  'Help'.

new_system([sys,'/','Help'])
set_param([sys,'/','Help'],'Location',[24,104,457,255])

add_block('built-in/Note',[sys,'/','Help/FM demodulator using the Adaptive Fourier Analyzer'])
set_param([sys,'/','Help/FM demodulator using the Adaptive Fourier Analyzer'],...
		'position',[210,5,215,10])

add_block('built-in/Note',[sys,'/',['Help/The input frequency is modulated by a signal generator. You can set different ',13,'frequencies, amplitudes, and waveforms.']])
set_param([sys,'/',['Help/The input frequency is modulated by a signal generator. You can set different ',13,'frequencies, amplitudes, and waveforms.']],...
		'position',[210,35,215,40])

add_block('built-in/Note',[sys,'/',['Help/If the modulator frequency is small enough, the system is ',13,'capable to track the input frequency.',13,'The error depends on the modulator frequency, ',13,'the carrier signal''s shape and frequency.']])
set_param([sys,'/',['Help/If the modulator frequency is small enough, the system is ',13,'capable to track the input frequency.',13,'The error depends on the modulator frequency, ',13,'the carrier signal''s shape and frequency.']],...
		'position',[210,75,215,80])
set_param([sys,'/','Help'],...
		'Mask Display','?')


%     Finished composite block 'Help'.

set_param([sys,'/','Help'],...
		'BackGround',7,...
		'Drop Shadow',4,...
		'position',[490,54,520,76])


%     Subsystem  ['Comet ',13,'XY Scope'].

new_system([sys,'/',['Comet ',13,'XY Scope']])
set_param([sys,'/',['Comet ',13,'XY Scope']],'Location',[4,75,454,330])

add_block('built-in/S-Function',[sys,'/',['Comet ',13,'XY Scope/S-function',13,'M file which plots',13,' complex trail']])
set_param([sys,'/',['Comet ',13,'XY Scope/S-function',13,'M file which plots',13,' complex trail']],...
		'function name','trplot',...
		'parameters','ax, N',...
		'position',[290,65,340,115])

add_block('built-in/Mux',[sys,'/',['Comet ',13,'XY Scope/Mux']])
set_param([sys,'/',['Comet ',13,'XY Scope/Mux']],...
		'inputs','2',...
		'position',[195,71,230,104])

add_block('built-in/Inport',[sys,'/',['Comet ',13,'XY Scope/x_axis',13,'']])
set_param([sys,'/',['Comet ',13,'XY Scope/x_axis',13,'']],...
		'position',[110,25,130,45])

add_block('built-in/Inport',[sys,'/',['Comet ',13,'XY Scope/y-axis']])
set_param([sys,'/',['Comet ',13,'XY Scope/y-axis']],...
		'Port','2',...
		'position',[110,110,130,130])
add_line([sys,'/',['Comet ',13,'XY Scope']],[135,120;190,95])
add_line([sys,'/',['Comet ',13,'XY Scope']],[135,35;190,80])
add_line([sys,'/',['Comet ',13,'XY Scope']],[235,90;285,90])
set_param([sys,'/',['Comet ',13,'XY Scope']],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[24,26,34,45,62,76,81],[55,61,72,79,81,76,70],[78,83,80,80],[70,70,74,66])',...
		'Mask Type','XY comet scope.')
set_param([sys,'/',['Comet ',13,'XY Scope']],...
		'Mask Dialogue','XY scope using MATLAB graph window.\nEnter plotting ranges.|x-min|x-max|y-min|y-max|Number of samples on display',...
		'Mask Translate','ax = [@1, @2, @3, @4];N=@5;')
set_param([sys,'/',['Comet ',13,'XY Scope']],...
		'Mask Help','XY Comet scope. The N latest samples are displayed.',...
		'Mask Entries','-1.1\/1.1\/-1.1\/1.1\/20\/')


%     Finished composite block ['Comet ',13,'XY Scope'].

set_param([sys,'/',['Comet ',13,'XY Scope']],...
		'position',[455,167,485,198])

add_block('built-in/Fcn',[sys,'/','Fund harmonic'])
set_param([sys,'/','Fund harmonic'],...
		'orientation',2,...
		'Expr','u[2]',...
		'position',[215,280,260,310])

add_block('built-in/Gain',[sys,'/','2pi'])
set_param([sys,'/','2pi'],...
		'orientation',2,...
		'Gain','2*pi',...
		'position',[170,283,190,307])

add_block('built-in/Note',[sys,'/',['frequency',13,'vector']])
set_param([sys,'/',['frequency',13,'vector']],...
		'position',[275,185,280,190])


%     Subsystem  'monitor: L'.

new_system([sys,'/','monitor: L'])
set_param([sys,'/','monitor: L'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','monitor: L/monitor S-fcn'])
set_param([sys,'/','monitor: L/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','monitor: L/in_1'])
set_param([sys,'/','monitor: L/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','monitor: L'],[40,90;50,90])
set_param([sys,'/','monitor: L'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','monitor: L'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','monitor: L'],...
		'Mask Entries','1\/')


%     Finished composite block 'monitor: L'.

set_param([sys,'/','monitor: L'],...
		'position',[320,229,355,251])


%     Subsystem  ['Frequency',13,'Adaptation'].

new_system([sys,'/',['Frequency',13,'Adaptation']])
set_param([sys,'/',['Frequency',13,'Adaptation']],'Location',[104,231,486,442])

add_block('built-in/Mux',[sys,'/',['Frequency',13,'Adaptation/Mux']])
set_param([sys,'/',['Frequency',13,'Adaptation/Mux']],...
		'inputs','2',...
		'position',[90,61,120,94])

add_block('built-in/S-Function',[sys,'/',['Frequency',13,'Adaptation/adaptation']])
set_param([sys,'/',['Frequency',13,'Adaptation/adaptation']],...
		'function name','adapt',...
		'parameters','alpha, init_freq',...
		'position',[150,55,200,105])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Adaptation/Real X1']])
set_param([sys,'/',['Frequency',13,'Adaptation/Real X1']],...
		'position',[20,40,40,60])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Adaptation/Imag X1']])
set_param([sys,'/',['Frequency',13,'Adaptation/Imag X1']],...
		'Port','2',...
		'position',[20,105,40,125])

add_block('built-in/MATLAB Fcn',[sys,'/',['Frequency',13,'Adaptation/L']])
set_param([sys,'/',['Frequency',13,'Adaptation/L']],...
		'MATLAB Fcn','(u(1))',...
		'Output Width','1',...
		'position',[255,58,310,102])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Adaptation/out_2']])
set_param([sys,'/',['Frequency',13,'Adaptation/out_2']],...
		'Port','2',...
		'position',[350,145,370,165])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Adaptation/out_1']])
set_param([sys,'/',['Frequency',13,'Adaptation/out_1']],...
		'position',[350,70,370,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Frequency',13,'Adaptation/freqency vector']])
set_param([sys,'/',['Frequency',13,'Adaptation/freqency vector']],...
		'MATLAB Fcn','(u(2:51))',...
		'Output Width','50',...
		'position',[255,133,310,177])
add_line([sys,'/',['Frequency',13,'Adaptation']],[205,80;250,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[230,80;230,155;250,155])
add_line([sys,'/',['Frequency',13,'Adaptation']],[125,80;145,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[45,50;65,50;65,70;85,70])
add_line([sys,'/',['Frequency',13,'Adaptation']],[315,80;345,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[45,115;65,115;65,85;85,85])
add_line([sys,'/',['Frequency',13,'Adaptation']],[315,155;345,155])
set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'Mask Display','Frequency \nAdaptation',...
		'Mask Type','Adaptation',...
		'Mask Dialogue','Adaptation Mechanism for AFA|Adaptation step-size (0.01...1):|Initial freqency (0..0.5):')
set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'Mask Translate','alpha=@1;init_freq=@2;',...
		'Mask Help','Adaptation mechanism for AFA. Input1-2: Re-ImX1, Output1: L, Output2: frequency vector.',...
		'Mask Entries','1\/1/11\/')


%     Finished composite block ['Frequency',13,'Adaptation'].

set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[300,264,365,306])


%     Subsystem  ['Ampitude',13,'Estimators'].

new_system([sys,'/',['Ampitude',13,'Estimators']])
set_param([sys,'/',['Ampitude',13,'Estimators']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Ampitude',13,'Estimators/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Ampitude',13,'Estimators/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Ampitude',13,'Estimators/x']])
set_param([sys,'/',['Ampitude',13,'Estimators/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Ampitude',13,'Estimators']],[90,65;125,65])
set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'Mask Entries','100\/-1.1\/1.1\/100\/''r-/g-/c-/y-/w-/m-/b-''\/1\/')


%     Finished composite block ['Ampitude',13,'Estimators'].

set_param([sys,'/',['Ampitude',13,'Estimators']],...
		'position',[530,110,560,150])


%     Subsystem  ['Complex',13,'Abs'].

new_system([sys,'/',['Complex',13,'Abs']])
set_param([sys,'/',['Complex',13,'Abs']],'Location',[154,254,709,464])

add_block('built-in/Sum',[sys,'/',['Complex',13,'Abs/Sum1']])
set_param([sys,'/',['Complex',13,'Abs/Sum1']],...
		'position',[325,110,345,130])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product1']])
set_param([sys,'/',['Complex',13,'Abs/Product1']],...
		'position',[265,140,290,160])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product']])
set_param([sys,'/',['Complex',13,'Abs/Product']],...
		'position',[265,85,290,105])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_1']])
set_param([sys,'/',['Complex',13,'Abs/in_1']],...
		'position',[155,80,175,100])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_2']])
set_param([sys,'/',['Complex',13,'Abs/in_2']],...
		'Port','2',...
		'position',[155,135,175,155])

add_block('built-in/Outport',[sys,'/',['Complex',13,'Abs/out_1']])
set_param([sys,'/',['Complex',13,'Abs/out_1']],...
		'position',[445,110,465,130])

add_block('built-in/MATLAB Fcn',[sys,'/',['Complex',13,'Abs/MATLAB Fcn']])
set_param([sys,'/',['Complex',13,'Abs/MATLAB Fcn']],...
		'MATLAB Fcn','sqrt',...
		'position',[370,105,420,135])
add_line([sys,'/',['Complex',13,'Abs']],[350,120;365,120])
add_line([sys,'/',['Complex',13,'Abs']],[295,150;300,150;300,125;320,125])
add_line([sys,'/',['Complex',13,'Abs']],[295,95;300,95;300,115;320,115])
add_line([sys,'/',['Complex',13,'Abs']],[180,145;260,145])
add_line([sys,'/',['Complex',13,'Abs']],[250,145;225,145;225,155;260,155])
add_line([sys,'/',['Complex',13,'Abs']],[180,90;260,90])
add_line([sys,'/',['Complex',13,'Abs']],[240,90;220,90;220,100;260,100])
add_line([sys,'/',['Complex',13,'Abs']],[425,120;440,120])
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Display','[Re, Im] \n->Abs',...
		'Mask Type','Complex Abs',...
		'Mask Dialogue','Absulute value of  a complex number')
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Help','Converts complex input (Real and Imag components) into absulute value. ')


%     Finished composite block ['Complex',13,'Abs'].

set_param([sys,'/',['Complex',13,'Abs']],...
		'position',[445,112,495,143])


%     Subsystem  ['Resonator ',13,'bank'].

new_system([sys,'/',['Resonator ',13,'bank']])
set_param([sys,'/',['Resonator ',13,'bank']],'Location',[4,42,618,417])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/input_signal']])
set_param([sys,'/',['Resonator ',13,'bank/input_signal']],...
		'position',[30,75,50,95])

add_block('built-in/S-Function',[sys,'/',['Resonator ',13,'bank/S-function: RFA']])
set_param([sys,'/',['Resonator ',13,'bank/S-function: RFA']],...
		'function name','resonfa',...
		'parameters',' CalcR',...
		'position',[230,70,280,120])

add_block('built-in/Mux',[sys,'/',['Resonator ',13,'bank/Mux']])
set_param([sys,'/',['Resonator ',13,'bank/Mux']],...
		'inputs','2',...
		'position',[160,76,190,109])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select y']])
set_param([sys,'/',['Resonator ',13,'bank/select y']],...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[330,15,380,45])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re']])
set_param([sys,'/',['Resonator ',13,'bank/select Re']],...
		'MATLAB Fcn','u(2:51)',...
		'Output Width','50',...
		'position',[330,80,380,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im']])
set_param([sys,'/',['Resonator ',13,'bank/select Im']],...
		'MATLAB Fcn','u(52:101)',...
		'Output Width','50',...
		'position',[335,145,385,175])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Re X1']],...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,210,385,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Im X1']],...
		'MATLAB Fcn','u(53)',...
		'Output Width','1',...
		'position',[335,275,385,305])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/output_signal_(y)']])
set_param([sys,'/',['Resonator ',13,'bank/output_signal_(y)']],...
		'position',[425,20,445,40])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X)']],...
		'Port','3',...
		'position',[425,150,445,170])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X)']],...
		'Port','2',...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X1)']],...
		'Port','4',...
		'position',[425,215,445,235])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X1)']],...
		'Port','5',...
		'position',[420,280,440,300])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/MATLAB Fcn']])
set_param([sys,'/',['Resonator ',13,'bank/MATLAB Fcn']],...
		'MATLAB Fcn','[u(:); inf*ones(50-length(u),1)]',...
		'Output Width','50',...
		'position',[75,125,125,155])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/FreqVector']])
set_param([sys,'/',['Resonator ',13,'bank/FreqVector']],...
		'Port','2',...
		'position',[30,130,50,150])
add_line([sys,'/',['Resonator ',13,'bank']],[130,140;135,140;135,100;155,100])
add_line([sys,'/',['Resonator ',13,'bank']],[55,140;70,140])
add_line([sys,'/',['Resonator ',13,'bank']],[285,95;325,95])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;315,160;330,160])
add_line([sys,'/',['Resonator ',13,'bank']],[315,160;315,225;330,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,225;315,290;330,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,290;415,290])
add_line([sys,'/',['Resonator ',13,'bank']],[390,225;420,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;325,30])
add_line([sys,'/',['Resonator ',13,'bank']],[390,160;420,160])
add_line([sys,'/',['Resonator ',13,'bank']],[385,30;420,30])
add_line([sys,'/',['Resonator ',13,'bank']],[385,95;420,95])
add_line([sys,'/',['Resonator ',13,'bank']],[55,85;155,85])
add_line([sys,'/',['Resonator ',13,'bank']],[195,95;225,95])
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Display','Resonator\nBank',...
		'Mask Type','Resonator bank',...
		'Mask Dialogue','Resonator bank |Calculation method of ''r'' (''alpha/N'', 0<apha<2; or ''FIR'')')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Translate','CalcR=@1;')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Help','Resonator bank structure. Input1: e, Input2: frequency values in rad/s. Output1: y, Output2: ReX, Output3: ImX. [Output4: ReX(1), Output5: ImX(1), for convenience only]')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Entries','''1.0/N''\/')


%     Finished composite block ['Resonator ',13,'bank'].

set_param([sys,'/',['Resonator ',13,'bank']],...
		'Drop Shadow',4,...
		'position',[305,121,375,199])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','-+',...
		'position',[260,122,280,158])

add_block('built-in/Note',[sys,'/','FM demodulation using the Adaptive Fourier Analyzer'])
set_param([sys,'/','FM demodulation using the Adaptive Fourier Analyzer'],...
		'Font Name','Times New Roman',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[285,10,290,15])

add_block('built-in/Note',[sys,'/','e'])
set_param([sys,'/','e'],...
		'position',[290,115,295,120])

add_block('built-in/Note',[sys,'/','y'])
set_param([sys,'/','y'],...
		'position',[405,110,410,115])

add_block('built-in/Scope',[sys,'/','Input Signal'])
set_param([sys,'/','Input Signal'],...
		'Vgain','3.000000',...
		'Hgain','100.000000',...
		'Vmax','6.000000',...
		'Hmax','200.000000',...
		'Window',[306,312,508,476],...
		'position',[240,62,260,88])


%     Subsystem  ['Controlled Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['Controlled Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],'Location',[4,61,318,253])

add_block('built-in/Outport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/out_1']],...
		'position',[215,60,235,80])

add_block('built-in/S-Function',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']],...
		'function name','blsigcon',...
		'parameters',' MaxN, Shape, sample',...
		'position',[125,59,185,81])

add_block('built-in/Mux',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Mux']],...
		'inputs','2',...
		'position',[55,51,90,84])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Freq']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator/Ampl']],...
		'Port','2',...
		'position',[15,90,35,110])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[190,70;210,70])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[95,70;120,70])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,35;50,60])
add_line([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],[40,100;50,75])
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Type','Controlled Band-limited signal generator')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Controlled Band Limited Signal Generator|Max number of harmonics:|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Translate','MaxN=@1; Shape=@2; sample=@3;',...
		'Mask Help','Band limited Signal Generator. Frequency: input 1;  Amplitude: input 2. ')
set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Entries','15\/''t''\/1\/')


%     Finished composite block ['Controlled Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['Controlled Band Limited ',13,'Signal Generator']],...
		'position',[160,131,205,169])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'generator']])
set_param([sys,'/',['Signal',13,'generator']],...
		'Peak','0.100000',...
		'Peak Range','5.000000',...
		'Freq','0.010000',...
		'Freq Range','5.000000',...
		'Wave','Sin',...
		'Units','Rads',...
		'position',[25,113,70,147])

add_block('built-in/Constant',[sys,'/','Constant:Freq'])
set_param([sys,'/','Constant:Freq'],...
		'Value','.3',...
		'position',[35,185,55,205])

add_block('built-in/Constant',[sys,'/','Constant:Ampl'])
set_param([sys,'/','Constant:Ampl'],...
		'Value','0.5',...
		'position',[35,240,55,260])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[150,201,185,234])


%     Subsystem  'monitor: f'.

new_system([sys,'/','monitor: f'])
set_param([sys,'/','monitor: f'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','monitor: f/monitor S-fcn'])
set_param([sys,'/','monitor: f/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','monitor: f/in_1'])
set_param([sys,'/','monitor: f/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','monitor: f'],[40,90;50,90])
set_param([sys,'/','monitor: f'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','monitor: f'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','monitor: f'],...
		'Mask Entries','10\/')


%     Finished composite block 'monitor: f'.

set_param([sys,'/','monitor: f'],...
		'orientation',2,...
		'position',[65,284,100,306])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'position',[95,122,115,158])


%     Subsystem  'Frequencies'.

new_system([sys,'/','Frequencies'])
set_param([sys,'/','Frequencies'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Frequencies/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Frequencies/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Frequencies/x'])
set_param([sys,'/','Frequencies/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Frequencies'],[90,65;125,65])
set_param([sys,'/','Frequencies'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','Frequencies'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/','Frequencies'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;',...
		'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/','Frequencies'],...
		'Mask Entries','100\/-1.1\/1.1\/100\/''r-/g-/c-/y-/w-/m-/b-''\/1\/')


%     Finished composite block 'Frequencies'.

set_param([sys,'/','Frequencies'],...
		'position',[210,200,240,240])
add_line(sys,[500,130;525,130])
add_line(sys,[380,145;400,145;400,120;440,120])
add_line(sys,[380,160;405,160;405,135;440,135])
add_line(sys,[380,130;395,130;395,110;230,110;230,130;255,130])
add_line(sys,[285,140;300,140])
add_line(sys,[380,175;450,175])
add_line(sys,[380,190;450,190])
add_line(sys,[295,275;285,275;285,240;315,240])
add_line(sys,[295,295;280,295;280,180;300,180])
add_line(sys,[210,295;195,295])
add_line(sys,[165,295;105,295])
add_line(sys,[295,295;265,295])
add_line(sys,[395,175;395,275;370,275])
add_line(sys,[405,190;405,295;370,295])
add_line(sys,[60,250;90,250;155,160])
add_line(sys,[75,130;90,130])
add_line(sys,[60,195;90,150])
add_line(sys,[120,140;155,140])
add_line(sys,[210,150;255,150])
add_line(sys,[220,150;220,75;235,75])
add_line(sys,[190,220;205,220])
add_line(sys,[130,295;130,225;145,225])
add_line(sys,[130,140;130,210;145,210])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
