function [ret,x0,str,ts,xts]=resdemos(t,x,u,flag);
%RESDEMOS	is the M-file description of the SIMULINK system named RESDEMOS.
%	The block-diagram can be displayed by typing: RESDEMOS.
%
%	SYS=RESDEMOS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RESDEMOS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RESDEMOS with a FLAG of zero:
%	[SIZES]=RESDEMOS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[71,44,586,258])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'resdemo1'.

new_system([sys,'/','resdemo1'])
set_param([sys,'/','resdemo1'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo1'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo1'')')


%     Finished composite block 'resdemo1'.

set_param([sys,'/','resdemo1'],...
		'position',[20,60,91,96])


%     Subsystem  'resdemo2'.

new_system([sys,'/','resdemo2'])
set_param([sys,'/','resdemo2'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo2'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo2'')')


%     Finished composite block 'resdemo2'.

set_param([sys,'/','resdemo2'],...
		'position',[120,60,191,96])


%     Subsystem  'resdemo3'.

new_system([sys,'/','resdemo3'])
set_param([sys,'/','resdemo3'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo3'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo3'')')


%     Finished composite block 'resdemo3'.

set_param([sys,'/','resdemo3'],...
		'position',[220,60,291,96])


%     Subsystem  'resdemo5'.

new_system([sys,'/','resdemo5'])
set_param([sys,'/','resdemo5'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo5'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo5'')')


%     Finished composite block 'resdemo5'.

set_param([sys,'/','resdemo5'],...
		'position',[415,60,486,96])


%     Subsystem  'resdemo4'.

new_system([sys,'/','resdemo4'])
set_param([sys,'/','resdemo4'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo4'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo4'')')


%     Finished composite block 'resdemo4'.

set_param([sys,'/','resdemo4'],...
		'position',[320,60,391,96])


%     Subsystem  'resdemo6'.

new_system([sys,'/','resdemo6'])
set_param([sys,'/','resdemo6'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo6'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo6'')')


%     Finished composite block 'resdemo6'.

set_param([sys,'/','resdemo6'],...
		'position',[20,145,91,181])


%     Subsystem  'resdemo7'.

new_system([sys,'/','resdemo7'])
set_param([sys,'/','resdemo7'],'Location',[-10,380,117,533])
set_param([sys,'/','resdemo7'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''resdemo7'')')


%     Finished composite block 'resdemo7'.

set_param([sys,'/','resdemo7'],...
		'position',[120,145,191,181])


%     Subsystem  'fddemo'.

new_system([sys,'/','fddemo'])
set_param([sys,'/','fddemo'],'Location',[-10,380,117,533])
set_param([sys,'/','fddemo'],...
		'Mask Display','DEMO',...
		'Mask Dialogue','eval(''fddemo'')')


%     Finished composite block 'fddemo'.

set_param([sys,'/','fddemo'],...
		'position',[415,145,486,181])

add_block('built-in/Note',[sys,'/','Resonator bank demos'])
set_param([sys,'/','Resonator bank demos'],...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[260,10,265,15])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
