function [sys, x0] = resonfa(t,x,u,flag, CalcR)

% function [sys, x0] = resonfa(t,x,u,flag, CalcR)
% Resonator bank stucture S-function.
% t, x, u, flag are conventional S-function parameters.
% CalcR determines the calculation method of the 'r' vector.
% CalcR is a string, which may be 'FIR', or 'alpha/N', where
% alpha is a number between zero and 1 (e.g. '0.5/N').

% uses calrs
% the frequency values are in the range of 0..0.5.

% (c) Gy. Simon, 28-07-1997

Max_L=49;


sample=1;	  % Sample time
ns=0;             % Number of continuous states
nd=3*(Max_L+1);   % Number of discrete states (re+imag of X; phi;)
ni=Max_L+2;	  % Number of inputs (1 input, Max_L+1 ResFreqs)
no=2*Max_L+3;	  % Number of outputs (1 y value, L+1 amplitude values: Real+Imag)


StartReX = 1;
EndReX	 = StartReX + Max_L;
StartImX = EndReX + 1 ;
EndImX	 = StartImX + Max_L;

StartPhi = EndImX + 1;
EndPhi	 = StartPhi + Max_L;
StartY   = EndPhi +1;

StartInp = 1;
%StartL   = StartInp+1;
%StartFreq= StartL+1;
StartFreq= StartInp+1;
EndFreq  = StartFreq+Max_L;


if  abs(flag)==2


	sample_hit = (rem(t+sample/1e8,sample) < sample/1e6);
	if sample_hit 

		%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
		% Resonator based filter bank state update
		%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	
		% state vars:
		% 
		% x(StartReX:EndReX)	Real part of the 'upper' resonator's output 
		% x(StartImX:EndImX) 	Imag part of the 'upper' resonator's output
		% x(StartPhi:EndPhi)	Phasor of c_vect
		% x(StartY)             Output
		%
		% input:
		%
		% u(StartInp)		Input value
		% u(StartFreq:EndFreq)	Resonator frequencies

		% get input value and resonator frequencies from u
		e=u(StartInp);
		finite_ix=find(finite(u));
		L=length(finite_ix)-2;
		if L>Max_L, error(['The value of L is too big. The maximum is ', num2str(Max_L), '.']), end
		ResFreqs=u(finite_ix(StartFreq:StartFreq+L));

		% get state vars and phi's from x
		X_vectOld=x(StartReX:StartReX+L)+j*x(StartImX:StartImX+L);
		phi=x(StartPhi:StartPhi+L);



		dc_ix=find((ResFreqs == 0)|(ResFreqs == 0.5));
		comp_ix=find((ResFreqs <0.5)& (ResFreqs >0));

		% Calculate r's
		N=2*length(comp_ix)+length(dc_ix);
		r=calcrs(ResFreqs,CalcR);		
		% calculate new c's and g's
		c_vect=exp(2*pi*j*phi);
		g_vect=r .* conj(c_vect);

		% Calculate new states
		X_vectNew=X_vectOld+g_vect*e; 
		phi=phi+ResFreqs;


		% make state var vector
		sys=zeros(nd,1);
		sys(StartReX:StartReX+L) = real(X_vectNew(1:L+1));
		sys(StartImX:StartImX+L) = imag(X_vectNew(1:L+1));
		sys(StartPhi:StartPhi+L) = phi;

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% End of resonator based filter bank state update
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	else
		sys = x;
	end
elseif flag == 3
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Resonator based filter bank output generation
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	finite_ix=find(finite(u));
	L=length(finite_ix)-2;
	if L
		ResFreqs=u(finite_ix(StartFreq:StartFreq+L));
		dc_ix=find((ResFreqs == 0)|(ResFreqs == 0.5));
		comp_ix=find((ResFreqs <0.5)& (ResFreqs >0));
		X_vect=x(StartReX:StartReX+L)+j*x(StartImX:StartImX+L);
		phi=x(StartPhi:StartPhi+L);
		c_vect=exp(2*pi*j*phi);
		y=0;
		if ~isempty(comp_ix)
			y=2*real(X_vect(comp_ix).'*c_vect(comp_ix));
        	end
        	if ~isempty(dc_ix)
			y=y+X_vect(dc_ix).'*c_vect(dc_ix);
		end

		Re_X_vect=x(StartReX:EndReX); Im_X_vect=x(StartImX:EndImX);
		sys=[y; Re_X_vect; Im_X_vect];
	else
		sys=zeros(no,1);
	end
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% End of resonator based filter bank output generation
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif flag ==4, 
	sys=ceil(t/sample+sample/1e8)*sample;

elseif flag == 0,
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Initialization of the resonator based filter bank 
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	sys=[ns,nd,no,ni,0,0];
	x0 =zeros(nd,1);
	x0(StartPhi:EndPhi)=zeros(Max_L+1,1);
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% End of initialization of the resonator based filter bank 
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

end

