function [ret,x0,str,ts,xts]=ressim(t,x,u,flag);
%RESSIM	is the M-file description of the SIMULINK system named RESSIM.
%	The block-diagram can be displayed by typing: RESSIM.
%
%	SYS=RESSIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RESSIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RESSIM with a FLAG of zero:
%	[SIZES]=RESSIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[16,74,617,172])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Resonator bank'.

new_system([sys,'/','Resonator bank'])
set_param([sys,'/','Resonator bank'],'Location',[55,108,429,344])

add_block('built-in/Note',[sys,'/','Resonator bank/Frequency vector --->'])
set_param([sys,'/','Resonator bank/Frequency vector --->'],...
		'position',[60,75,65,80])

add_block('built-in/Note',[sys,'/','Resonator bank/Input --->'])
set_param([sys,'/','Resonator bank/Input --->'],...
		'position',[50,45,55,50])

add_block('built-in/Sum',[sys,'/','Resonator bank/subs'])
set_param([sys,'/','Resonator bank/subs'],...
		'inputs','-+',...
		'position',[85,27,105,63])


%     Subsystem  ['Resonator bank/Resonator ',13,'bank'].

new_system([sys,'/',['Resonator bank/Resonator ',13,'bank']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],'Location',[4,42,618,417])

add_block('built-in/Inport',[sys,'/',['Resonator bank/Resonator ',13,'bank/input_signal']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/input_signal']],...
		'position',[30,75,50,95])

add_block('built-in/S-Function',[sys,'/',['Resonator bank/Resonator ',13,'bank/S-function: RFA']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/S-function: RFA']],...
		'function name','resonfa',...
		'parameters',' CalcR',...
		'position',[230,70,280,120])

add_block('built-in/Mux',[sys,'/',['Resonator bank/Resonator ',13,'bank/Mux']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/Mux']],...
		'inputs','2',...
		'position',[160,76,190,109])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/select y']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/select y']],...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[330,15,380,45])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/select Re']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/select Re']],...
		'MATLAB Fcn','u(2:51)',...
		'Output Width','50',...
		'position',[330,80,380,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/select Im']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/select Im']],...
		'MATLAB Fcn','u(52:101)',...
		'Output Width','50',...
		'position',[335,145,385,175])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/select Re X1']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/select Re X1']],...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,210,385,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/select Im X1']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/select Im X1']],...
		'MATLAB Fcn','u(53)',...
		'Output Width','1',...
		'position',[335,275,385,305])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Resonator ',13,'bank/output_signal_(y)']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/output_signal_(y)']],...
		'position',[425,20,445,40])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Resonator ',13,'bank/Im(X)']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/Im(X)']],...
		'Port','3',...
		'position',[425,150,445,170])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Resonator ',13,'bank/Re(X)']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/Re(X)']],...
		'Port','2',...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Resonator ',13,'bank/Re(X1)']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/Re(X1)']],...
		'Port','4',...
		'position',[425,215,445,235])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Resonator ',13,'bank/Im(X1)']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/Im(X1)']],...
		'Port','5',...
		'position',[420,280,440,300])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Resonator ',13,'bank/MATLAB Fcn']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/MATLAB Fcn']],...
		'MATLAB Fcn','[u(:); inf*ones(50-length(u),1)]',...
		'Output Width','50',...
		'position',[75,125,125,155])

add_block('built-in/Inport',[sys,'/',['Resonator bank/Resonator ',13,'bank/FreqVector']])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank/FreqVector']],...
		'Port','2',...
		'position',[30,130,50,150])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[130,140;135,140;135,100;155,100])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[55,140;70,140])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[285,95;325,95])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[315,95;315,160;330,160])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[315,160;315,225;330,225])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[315,225;315,290;330,290])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[390,290;415,290])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[390,225;420,225])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[315,95;325,30])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[390,160;420,160])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[385,30;420,30])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[385,95;420,95])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[55,85;155,85])
add_line([sys,'/',['Resonator bank/Resonator ',13,'bank']],[195,95;225,95])
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],...
		'Mask Display','Resonator\nBank',...
		'Mask Type','Resonator bank',...
		'Mask Dialogue','Resonator bank |Calculation method of ''r'' (''alpha/N'', 0<apha<2; or ''FIR'')')
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],...
		'Mask Translate','CalcR=@1;')
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],...
		'Mask Help','Resonator bank structure. Input1: e, Input2: frequency values in rad/s. Output1: y, Output2: ReX, Output3: ImX. [Output4: ReX(1), Output5: ImX(1), for convenience only]')
set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],...
		'Mask Entries','''1/N''\/')


%     Finished composite block ['Resonator bank/Resonator ',13,'bank'].

set_param([sys,'/',['Resonator bank/Resonator ',13,'bank']],...
		'Drop Shadow',4,...
		'position',[125,26,195,104])

add_block('built-in/Note',[sys,'/','Resonator bank/L <---'])
set_param([sys,'/','Resonator bank/L <---'],...
		'position',[100,140,105,145])

add_block('built-in/Note',[sys,'/','Resonator bank/Frequency vector <---'])
set_param([sys,'/','Resonator bank/Frequency vector <---'],...
		'position',[65,165,70,170])


%     Subsystem  ['Resonator bank/Frequency',13,'Adaptation'].

new_system([sys,'/',['Resonator bank/Frequency',13,'Adaptation']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],'Location',[104,231,486,442])

add_block('built-in/Mux',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/Mux']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/Mux']],...
		'inputs','2',...
		'position',[90,61,120,94])

add_block('built-in/S-Function',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/adaptation']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/adaptation']],...
		'function name','adapt',...
		'parameters','alpha, init_freq',...
		'position',[150,55,200,105])

add_block('built-in/Inport',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/Real X1']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/Real X1']],...
		'position',[20,40,40,60])

add_block('built-in/Inport',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/Imag X1']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/Imag X1']],...
		'Port','2',...
		'position',[20,105,40,125])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/L']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/L']],...
		'MATLAB Fcn','(u(1))',...
		'Output Width','1',...
		'position',[255,58,310,102])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/out_2']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/out_2']],...
		'Port','2',...
		'position',[350,145,370,165])

add_block('built-in/Outport',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/out_1']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/out_1']],...
		'position',[350,70,370,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator bank/Frequency',13,'Adaptation/freqency vector']])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation/freqency vector']],...
		'MATLAB Fcn','(u(2:51))',...
		'Output Width','50',...
		'position',[255,133,310,177])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[205,80;250,80])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[230,80;230,155;250,155])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[125,80;145,80])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[45,50;65,50;65,70;85,70])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[315,80;345,80])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[45,115;65,115;65,85;85,85])
add_line([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],[315,155;345,155])
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],...
		'Mask Display','Frequency \nAdaptation',...
		'Mask Type','Adaptation')
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],...
		'Mask Dialogue','Adaptation Mechanism for AFA|Adaptation step-size (0.01...1):|Initial freqency (0..0.5):',...
		'Mask Translate','alpha=@1;init_freq=@2;')
set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],...
		'Mask Help','Adaptation mechanism for AFA. Input1-2: Re-ImX1, Output1: L, Output2: frequency vector.',...
		'Mask Entries','1\/1/11\/')


%     Finished composite block ['Resonator bank/Frequency',13,'Adaptation'].

set_param([sys,'/',['Resonator bank/Frequency',13,'Adaptation']],...
		'orientation',2,...
		'Drop Shadow',4,...
		'position',[125,144,190,186])

add_block('built-in/Note',[sys,'/','Resonator bank/---> y'])
set_param([sys,'/','Resonator bank/---> y'],...
		'position',[230,25,235,30])

add_block('built-in/Note',[sys,'/','Resonator bank/---> Im X1'])
set_param([sys,'/','Resonator bank/---> Im X1'],...
		'position',[235,85,240,90])

add_block('built-in/Note',[sys,'/','Resonator bank/---> Re X1'])
set_param([sys,'/','Resonator bank/---> Re X1'],...
		'position',[235,70,240,75])

add_block('built-in/Note',[sys,'/','Resonator bank/---> Im X'])
set_param([sys,'/','Resonator bank/---> Im X'],...
		'position',[230,55,235,60])

add_block('built-in/Note',[sys,'/','Resonator bank/---> Re X'])
set_param([sys,'/','Resonator bank/---> Re X'],...
		'position',[230,40,235,45])

add_block('built-in/Note',[sys,'/','Resonator bank/<--- Re X1'])
set_param([sys,'/','Resonator bank/<--- Re X1'],...
		'position',[225,140,230,145])

add_block('built-in/Note',[sys,'/','Resonator bank/<--- Im X1'])
set_param([sys,'/','Resonator bank/<--- Im X1'],...
		'position',[225,165,230,170])


%     Subsystem  ['Resonator bank/Resonator Bank',13,'Demos'].

new_system([sys,'/',['Resonator bank/Resonator Bank',13,'Demos']])
set_param([sys,'/',['Resonator bank/Resonator Bank',13,'Demos']],'Location',[-10,380,117,533])
set_param([sys,'/',['Resonator bank/Resonator Bank',13,'Demos']],...
		'Mask Display','DEMOS',...
		'Mask Dialogue','eval(''resdemos'')')


%     Finished composite block ['Resonator bank/Resonator Bank',13,'Demos'].

set_param([sys,'/',['Resonator bank/Resonator Bank',13,'Demos']],...
		'position',[290,30,361,66])
add_line([sys,'/','Resonator bank'],[110,45;120,45])
add_line([sys,'/','Resonator bank'],[200,35;210,35;210,20;40,20;40,35;80,35])


%     Finished composite block 'Resonator bank'.

set_param([sys,'/','Resonator bank'],...
		'position',[145,10,185,61])


%     Subsystem  'Other useful blocks'.

new_system([sys,'/','Other useful blocks'])
set_param([sys,'/','Other useful blocks'],'Location',[205,42,563,369])


%     Subsystem  'Other useful blocks/AND'.

new_system([sys,'/','Other useful blocks/AND'])
set_param([sys,'/','Other useful blocks/AND'],'Location',[59,237,323,377])

add_block('built-in/Outport',[sys,'/','Other useful blocks/AND/out_1'])
set_param([sys,'/','Other useful blocks/AND/out_1'],...
		'position',[215,65,235,85])

add_block('built-in/Combinatorial Logic',[sys,'/','Other useful blocks/AND/AND'])
set_param([sys,'/','Other useful blocks/AND/AND'],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Mux',[sys,'/','Other useful blocks/AND/Mux'])
set_param([sys,'/','Other useful blocks/AND/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Inport',[sys,'/','Other useful blocks/AND/in_1'])
set_param([sys,'/','Other useful blocks/AND/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/','Other useful blocks/AND/in_2'])
set_param([sys,'/','Other useful blocks/AND/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])
add_line([sys,'/','Other useful blocks/AND'],[100,75;125,75])
add_line([sys,'/','Other useful blocks/AND'],[40,65;60,65])
add_line([sys,'/','Other useful blocks/AND'],[40,80;60,80])
add_line([sys,'/','Other useful blocks/AND'],[190,75;210,75])
set_param([sys,'/','Other useful blocks/AND'],...
		'Mask Display','&',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block 'Other useful blocks/AND'.

set_param([sys,'/','Other useful blocks/AND'],...
		'position',[35,29,65,51])


%     Subsystem  'Other useful blocks/OR'.

new_system([sys,'/','Other useful blocks/OR'])
set_param([sys,'/','Other useful blocks/OR'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Other useful blocks/OR/in_2'])
set_param([sys,'/','Other useful blocks/OR/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/','Other useful blocks/OR/in_1'])
set_param([sys,'/','Other useful blocks/OR/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/','Other useful blocks/OR/Mux'])
set_param([sys,'/','Other useful blocks/OR/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/','Other useful blocks/OR/OR'])
set_param([sys,'/','Other useful blocks/OR/OR'],...
		'Truth Table','[0;1;1;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Other useful blocks/OR/out_1'])
set_param([sys,'/','Other useful blocks/OR/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Other useful blocks/OR'],[190,75;210,75])
add_line([sys,'/','Other useful blocks/OR'],[40,80;60,80])
add_line([sys,'/','Other useful blocks/OR'],[40,65;60,65])
add_line([sys,'/','Other useful blocks/OR'],[100,75;125,75])
set_param([sys,'/','Other useful blocks/OR'],...
		'Mask Display','1',...
		'Mask Type','OR',...
		'Mask Dialogue','OR Gate',...
		'Mask Help','Calculates the logical OR of the two inputs.')


%     Finished composite block 'Other useful blocks/OR'.

set_param([sys,'/','Other useful blocks/OR'],...
		'position',[100,29,130,51])


%     Subsystem  'Other useful blocks/NOT'.

new_system([sys,'/','Other useful blocks/NOT'])
set_param([sys,'/','Other useful blocks/NOT'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Other useful blocks/NOT/in_1'])
set_param([sys,'/','Other useful blocks/NOT/in_1'],...
		'position',[60,65,80,85])

add_block('built-in/Combinatorial Logic',[sys,'/','Other useful blocks/NOT/NOT'])
set_param([sys,'/','Other useful blocks/NOT/NOT'],...
		'Truth Table','[1;0]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Other useful blocks/NOT/out_1'])
set_param([sys,'/','Other useful blocks/NOT/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Other useful blocks/NOT'],[85,75;125,75])
add_line([sys,'/','Other useful blocks/NOT'],[190,75;210,75])
set_param([sys,'/','Other useful blocks/NOT'],...
		'Mask Display','NOT',...
		'Mask Type','NOT',...
		'Mask Dialogue','NOT Gate',...
		'Mask Help','Calculates the logical NOT operation of the input.')


%     Finished composite block 'Other useful blocks/NOT'.

set_param([sys,'/','Other useful blocks/NOT'],...
		'position',[160,29,190,51])


%     Subsystem  ['Other useful blocks/Complex',13,'Abs'].

new_system([sys,'/',['Other useful blocks/Complex',13,'Abs']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs']],'Location',[154,254,709,464])

add_block('built-in/MATLAB Fcn',[sys,'/',['Other useful blocks/Complex',13,'Abs/MATLAB Fcn']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/MATLAB Fcn']],...
		'MATLAB Fcn','sqrt',...
		'position',[370,105,420,135])

add_block('built-in/Outport',[sys,'/',['Other useful blocks/Complex',13,'Abs/out_1']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/out_1']],...
		'position',[445,110,465,130])

add_block('built-in/Inport',[sys,'/',['Other useful blocks/Complex',13,'Abs/in_2']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/in_2']],...
		'Port','2',...
		'position',[155,135,175,155])

add_block('built-in/Inport',[sys,'/',['Other useful blocks/Complex',13,'Abs/in_1']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/in_1']],...
		'position',[155,80,175,100])

add_block('built-in/Product',[sys,'/',['Other useful blocks/Complex',13,'Abs/Product']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/Product']],...
		'position',[265,85,290,105])

add_block('built-in/Product',[sys,'/',['Other useful blocks/Complex',13,'Abs/Product1']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/Product1']],...
		'position',[265,140,290,160])

add_block('built-in/Sum',[sys,'/',['Other useful blocks/Complex',13,'Abs/Sum1']])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs/Sum1']],...
		'position',[325,110,345,130])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[425,120;440,120])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[180,90;260,90])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[240,90;220,90;220,100;260,100])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[180,145;260,145])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[250,145;225,145;225,155;260,155])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[295,95;300,95;300,115;320,115])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[295,150;300,150;300,125;320,125])
add_line([sys,'/',['Other useful blocks/Complex',13,'Abs']],[350,120;365,120])
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs']],...
		'Mask Display','[Re, Im] \n->Abs',...
		'Mask Type','Complex Abs',...
		'Mask Dialogue','Absulute value of  a complex number')
set_param([sys,'/',['Other useful blocks/Complex',13,'Abs']],...
		'Mask Help','Converts complex input (Real and Imag components) into absulute value. ')


%     Finished composite block ['Other useful blocks/Complex',13,'Abs'].

set_param([sys,'/',['Other useful blocks/Complex',13,'Abs']],...
		'position',[105,80,160,120])


%     Subsystem  'Other useful blocks/Counter'.

new_system([sys,'/','Other useful blocks/Counter'])
set_param([sys,'/','Other useful blocks/Counter'],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/','Other useful blocks/Counter/S-function: counter'])
set_param([sys,'/','Other useful blocks/Counter/S-function: counter'],...
		'function name','counter',...
		'parameters','threshold, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/','Other useful blocks/Counter/input'])
set_param([sys,'/','Other useful blocks/Counter/input'],...
		'position',[35,100,55,120])

add_block('built-in/Outport',[sys,'/','Other useful blocks/Counter/Output'])
set_param([sys,'/','Other useful blocks/Counter/Output'],...
		'position',[190,100,210,120])
add_line([sys,'/','Other useful blocks/Counter'],[60,110;80,110])
add_line([sys,'/','Other useful blocks/Counter'],[145,110;185,110])
set_param([sys,'/','Other useful blocks/Counter'],...
		'Mask Display','CT',...
		'Mask Type','Counter',...
		'Mask Dialogue','Counter. Indicates the time since input >= threshold|Threshold:|Min update interval:')
set_param([sys,'/','Other useful blocks/Counter'],...
		'Mask Translate','threshold=@1;sample=@2;',...
		'Mask Help','Counter block.',...
		'Mask Entries','0\/1\/')


%     Finished composite block 'Other useful blocks/Counter'.

set_param([sys,'/','Other useful blocks/Counter'],...
		'position',[35,91,70,119])


%     Subsystem  'Other useful blocks/counter demo'.

new_system([sys,'/','Other useful blocks/counter demo'])
set_param([sys,'/','Other useful blocks/counter demo'],'Location',[-10,380,117,533])
set_param([sys,'/','Other useful blocks/counter demo'],...
		'Mask Display','Demo illustrating\n the usage of\nthe counter',...
		'Mask Dialogue','eval(''compdemo'')')


%     Finished composite block 'Other useful blocks/counter demo'.

set_param([sys,'/','Other useful blocks/counter demo'],...
		'position',[25,165,126,201])


%     Finished composite block 'Other useful blocks'.

set_param([sys,'/','Other useful blocks'],...
		'position',[245,10,285,61])


%     Subsystem  'New sources//sinks'.

new_system([sys,'/','New sources//sinks'])
set_param([sys,'/','New sources//sinks'],'Location',[142,131,574,456])


%     Subsystem  ['New sources//sinks/Controlled Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],'Location',[4,61,318,253])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Ampl']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Ampl']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Freq']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Freq']],...
		'position',[15,25,35,45])

add_block('built-in/Mux',[sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Mux']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Mux']],...
		'inputs','2',...
		'position',[55,51,90,84])

add_block('built-in/S-Function',[sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/Cotrolled Band Limited',13,'Signal Generator']],...
		'function name','blsigcon',...
		'parameters',' MaxN, Shape, sample',...
		'position',[125,59,185,81])

add_block('built-in/Outport',[sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator/out_1']],...
		'position',[215,60,235,80])
add_line([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],[40,100;50,75])
add_line([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],[40,35;50,60])
add_line([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],[95,70;120,70])
add_line([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],[190,70;210,70])
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])')
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Type','Controlled Band-limited signal generator')
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Controlled Band Limited Signal Generator|Max number of harmonics:|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Translate','MaxN=@1; Shape=@2; sample=@3;',...
		'Mask Help','Band limited Signal Generator. Frequency: input 1;  Amplitude: input 2. ')
set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'Mask Entries','15\/''t''\/1\/')


%     Finished composite block ['New sources//sinks/Controlled Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['New sources//sinks/Controlled Band Limited ',13,'Signal Generator']],...
		'position',[90,141,135,179])


%     Subsystem  ['New sources//sinks/Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],'Location',[4,80,149,205])

add_block('built-in/Outport',[sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator/out_1']],...
		'position',[125,60,145,80])

add_block('built-in/S-Function',[sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator/Band Limited',13,'Signal Generator']])
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator/Band Limited',13,'Signal Generator']],...
		'function name','blsiggen',...
		'parameters','Freq, Ampl, Phase, MaxN, Shape, sample',...
		'position',[50,59,110,81])
add_line([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],[115,70;120,70])
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])')
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'Mask Type','Band-limited signal generator')
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Band Limited Signal Generator|Frequency (rad/sec):|Amplitude:|Initial Phase (can not be changed in run-time):|Max number of harmonics (can not be changed in run-time):|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'Mask Translate','Freq=@1; Ampl=@2; Phase=@3; MaxN=@4; Shape=@5; sample=@6;',...
		'Mask Help','Generates different waveforms from limited number of sinusoidals.')
set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'Mask Entries','0.5\/1\/0\/15\/''s''\/1\/')


%     Finished composite block ['New sources//sinks/Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['New sources//sinks/Band Limited ',13,'Signal Generator']],...
		'position',[90,61,135,99])

add_block('built-in/Note',[sys,'/','New sources//sinks/Sources'])
set_param([sys,'/','New sources//sinks/Sources'],...
		'Font Size',12,...
		'position',[110,10,115,15])

add_block('built-in/Note',[sys,'/','New sources//sinks/Frequency --->'])
set_param([sys,'/','New sources//sinks/Frequency --->'],...
		'position',[40,135,45,140])

add_block('built-in/Note',[sys,'/','New sources//sinks/Amplitude --->'])
set_param([sys,'/','New sources//sinks/Amplitude --->'],...
		'position',[40,155,45,160])


%     Subsystem  'New sources//sinks/monitor'.

new_system([sys,'/','New sources//sinks/monitor'])
set_param([sys,'/','New sources//sinks/monitor'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','New sources//sinks/monitor/monitor S-fcn'])
set_param([sys,'/','New sources//sinks/monitor/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','New sources//sinks/monitor/in_1'])
set_param([sys,'/','New sources//sinks/monitor/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','New sources//sinks/monitor'],[40,90;50,90])
set_param([sys,'/','New sources//sinks/monitor'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','New sources//sinks/monitor'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','New sources//sinks/monitor'],...
		'Mask Entries','1\/')


%     Finished composite block 'New sources//sinks/monitor'.

set_param([sys,'/','New sources//sinks/monitor'],...
		'position',[260,59,295,81])


%     Subsystem  'New sources//sinks/LED'.

new_system([sys,'/','New sources//sinks/LED'])
set_param([sys,'/','New sources//sinks/LED'],'Location',[92,116,322,316])

add_block('built-in/Inport',[sys,'/','New sources//sinks/LED/in_1'])
set_param([sys,'/','New sources//sinks/LED/in_1'],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/','New sources//sinks/LED/S-function: led'])
set_param([sys,'/','New sources//sinks/LED/S-function: led'],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])
add_line([sys,'/','New sources//sinks/LED'],[60,110;80,110])
set_param([sys,'/','New sources//sinks/LED'],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:')
set_param([sys,'/','New sources//sinks/LED'],...
		'Mask Translate','COLOR=@1;sample=@2;',...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[6 1 7]\/1\/')


%     Finished composite block 'New sources//sinks/LED'.

set_param([sys,'/','New sources//sinks/LED'],...
		'position',[270,100,290,110])


%     Subsystem  ['New sources//sinks/Comet ',13,'XY Scope'].

new_system([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],'Location',[4,75,454,330])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Comet ',13,'XY Scope/y-axis']])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope/y-axis']],...
		'Port','2',...
		'position',[110,110,130,130])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Comet ',13,'XY Scope/x_axis',13,'']])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope/x_axis',13,'']],...
		'position',[110,25,130,45])

add_block('built-in/Mux',[sys,'/',['New sources//sinks/Comet ',13,'XY Scope/Mux']])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope/Mux']],...
		'inputs','2',...
		'position',[195,71,230,104])

add_block('built-in/S-Function',[sys,'/',['New sources//sinks/Comet ',13,'XY Scope/S-function',13,'M file which plots',13,' complex trail']])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope/S-function',13,'M file which plots',13,' complex trail']],...
		'function name','trplot',...
		'parameters','ax, N',...
		'position',[290,65,340,115])
add_line([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],[235,90;285,90])
add_line([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],[135,35;190,80])
add_line([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],[135,120;190,95])
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[24,26,34,45,62,76,81],[55,61,72,79,81,76,70],[78,83,80,80],[70,70,74,66])')
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],...
		'Mask Type','XY comet scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nEnter plotting ranges.|x-min|x-max|y-min|y-max|Number of samples on display')
set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],...
		'Mask Translate','ax = [@1, @2, @3, @4];N=@5;',...
		'Mask Help','XY Comet scope. The N latest samples are displayed.',...
		'Mask Entries','-1.1\/1.1\/-1.1\/1.1\/20\/')


%     Finished composite block ['New sources//sinks/Comet ',13,'XY Scope'].

set_param([sys,'/',['New sources//sinks/Comet ',13,'XY Scope']],...
		'position',[265,132,295,183])

add_block('built-in/Note',[sys,'/','New sources//sinks/X --->'])
set_param([sys,'/','New sources//sinks/X --->'],...
		'position',[240,135,245,140])

add_block('built-in/Note',[sys,'/','New sources//sinks/Y --->'])
set_param([sys,'/','New sources//sinks/Y --->'],...
		'position',[240,160,245,165])


%     Subsystem  'New sources//sinks/AM demo with CBLSG'.

new_system([sys,'/','New sources//sinks/AM demo with CBLSG'])
set_param([sys,'/','New sources//sinks/AM demo with CBLSG'],'Location',[-10,380,117,533])
set_param([sys,'/','New sources//sinks/AM demo with CBLSG'],...
		'Mask Display','AM Demo',...
		'Mask Dialogue','eval(''amdemo'')')


%     Finished composite block 'New sources//sinks/AM demo with CBLSG'.

set_param([sys,'/','New sources//sinks/AM demo with CBLSG'],...
		'position',[40,220,111,256])


%     Subsystem  'New sources//sinks/Other components'.

new_system([sys,'/','New sources//sinks/Other components'])
set_param([sys,'/','New sources//sinks/Other components'],'Location',[-10,380,117,533])
set_param([sys,'/','New sources//sinks/Other components'],...
		'Mask Display','Demo illustrating\n the usage of\nother components',...
		'Mask Dialogue','eval(''compdemo'')')


%     Finished composite block 'New sources//sinks/Other components'.

set_param([sys,'/','New sources//sinks/Other components'],...
		'position',[260,220,361,256])


%     Subsystem  'New sources//sinks/FM demo with CBLSG'.

new_system([sys,'/','New sources//sinks/FM demo with CBLSG'])
set_param([sys,'/','New sources//sinks/FM demo with CBLSG'],'Location',[-10,380,117,533])
set_param([sys,'/','New sources//sinks/FM demo with CBLSG'],...
		'Mask Display','FM Demo',...
		'Mask Dialogue','eval(''fmdemo'')')


%     Finished composite block 'New sources//sinks/FM demo with CBLSG'.

set_param([sys,'/','New sources//sinks/FM demo with CBLSG'],...
		'position',[155,220,226,256])


%     Subsystem  ['New sources//sinks/Spectrum Analyzer',13,'(modified)'].

new_system([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],'Location',[4,42,375,227])

add_block('built-in/Mux',[sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/Mux']])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/Mux']],...
		'inputs','2',...
		'position',[145,71,175,104])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/system output']])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/system output']],...
		'Port','2',...
		'position',[55,110,75,130])

add_block('built-in/S-Function',[sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/S-function block',13,'which calls M-file']])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/S-function block',13,'which calls M-file']],...
		'function name','sfuntf1',...
		'parameters','fftpts,npts,HowOften,offset,ts,0',...
		'position',[250,72,295,108])

add_block('built-in/Inport',[sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/system input']])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)/system input']],...
		'position',[55,30,75,50])
add_line([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],[80,120;110,120;110,95;140,95])
add_line([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],[80,40;110,40;110,80;140,80])
add_line([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],[180,90;245,90])
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Display','plot(0,0,100,100,[11,93,93,11,11],[90,90,40,40,90],[90,80,72,64,55,45,41,36,20],[50,50,52,59,67,75,78,80,80])')
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Type','Spectrum analyzer.')
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Dialogue','Spectrum analyser using graph window.\nHook input 1 to system input.\nHook input 2 to system output.|Length of buffer:|Number of points for fft:|Plot after how many points:|Sample time:')
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Translate','npts=@1; fftpts=@2; HowOften=@3; ts=@4(1); if length(@4) > 1, offset = @4(2), else, offset = 0; end')
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Help','Hook the system''s input to the first port of this block and the system''s output to second port. Results are displayed as the frequency response of this system. Use signals with high harmonic content for best results. Now works with constant transfer functions.')
set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Mask Entries','256\/256\/64\/1\/')


%     Finished composite block ['New sources//sinks/Spectrum Analyzer',13,'(modified)'].

set_param([sys,'/',['New sources//sinks/Spectrum Analyzer',13,'(modified)']],...
		'Drop Shadow',4,...
		'position',[350,55,380,95])

add_block('built-in/Note',[sys,'/','New sources//sinks/Sinks'])
set_param([sys,'/','New sources//sinks/Sinks'],...
		'Font Size',12,...
		'position',[305,15,310,20])


%     Finished composite block 'New sources//sinks'.

set_param([sys,'/','New sources//sinks'],...
		'position',[45,10,85,61])


%     Subsystem  'Simulink'.

new_system([sys,'/','Simulink'])
set_param([sys,'/','Simulink'],'Location',[-10,380,117,533])
set_param([sys,'/','Simulink'],...
		'Mask Display','Full Block\nLibrary',...
		'Mask Dialogue','eval(''simulink'')')


%     Finished composite block 'Simulink'.

set_param([sys,'/','Simulink'],...
		'position',[505,19,576,55])


%     Subsystem  ['Most commonly',13,'used blocks'].

new_system([sys,'/',['Most commonly',13,'used blocks']])
set_param([sys,'/',['Most commonly',13,'used blocks']],'Location',[-10,380,117,533])
set_param([sys,'/',['Most commonly',13,'used blocks']],...
		'Mask Display','Block\nLibrary',...
		'Mask Dialogue','eval(''blocklib'')')


%     Finished composite block ['Most commonly',13,'used blocks'].

set_param([sys,'/',['Most commonly',13,'used blocks']],...
		'position',[420,20,491,56])


%     Subsystem  ['Resonator Bank',13,'Demos'].

new_system([sys,'/',['Resonator Bank',13,'Demos']])
set_param([sys,'/',['Resonator Bank',13,'Demos']],'Location',[-10,380,117,533])
set_param([sys,'/',['Resonator Bank',13,'Demos']],...
		'Mask Display','DEMOS',...
		'Mask Dialogue','eval(''resdemos'')')


%     Finished composite block ['Resonator Bank',13,'Demos'].

set_param([sys,'/',['Resonator Bank',13,'Demos']],...
		'position',[325,20,396,56])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
