function [ret,x0,str,ts,xts]=rfatest3(t,x,u,flag);
%RFATEST3	is the M-file description of the SIMULINK system named RFATEST3.
%	The block-diagram can be displayed by typing: RFATEST3.
%
%	SYS=RFATEST3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes RFATEST3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling RFATEST3 with a FLAG of zero:
%	[SIZES]=RFATEST3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,49,628,460])
     open_system(sys)
end;
set_param(sys,'BackGround',7)
set_param(sys,'algorithm',     'RK-23')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','3.000000',...
		'Hgain','100.000000',...
		'Vmax','6.000000',...
		'Hmax','200.000000',...
		'Window',[19,297,221,461],...
		'position',[240,47,260,73])

add_block('built-in/Note',[sys,'/','y'])
set_param([sys,'/','y'],...
		'position',[350,105,355,110])

add_block('built-in/Note',[sys,'/','e'])
set_param([sys,'/','e'],...
		'position',[235,110,240,115])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','3.000000',...
		'Hgain','100.000000',...
		'Vmax','6.000000',...
		'Hmax','200.000000',...
		'Window',[783,347,1105,727],...
		'position',[390,50,410,80])


%     Subsystem  ['Frequency',13,'Adaptation'].

new_system([sys,'/',['Frequency',13,'Adaptation']])
set_param([sys,'/',['Frequency',13,'Adaptation']],'Location',[104,231,486,442])

add_block('built-in/Mux',[sys,'/',['Frequency',13,'Adaptation/Mux']])
set_param([sys,'/',['Frequency',13,'Adaptation/Mux']],...
		'inputs','2',...
		'position',[90,61,120,94])

add_block('built-in/S-Function',[sys,'/',['Frequency',13,'Adaptation/adaptation']])
set_param([sys,'/',['Frequency',13,'Adaptation/adaptation']],...
		'function name','adapt',...
		'parameters','alpha, init_freq',...
		'position',[150,55,200,105])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Adaptation/Real X1']])
set_param([sys,'/',['Frequency',13,'Adaptation/Real X1']],...
		'position',[20,40,40,60])

add_block('built-in/Inport',[sys,'/',['Frequency',13,'Adaptation/Imag X1']])
set_param([sys,'/',['Frequency',13,'Adaptation/Imag X1']],...
		'Port','2',...
		'position',[20,105,40,125])

add_block('built-in/MATLAB Fcn',[sys,'/',['Frequency',13,'Adaptation/L']])
set_param([sys,'/',['Frequency',13,'Adaptation/L']],...
		'MATLAB Fcn','(u(1))',...
		'Output Width','1',...
		'position',[255,58,310,102])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Adaptation/out_2']])
set_param([sys,'/',['Frequency',13,'Adaptation/out_2']],...
		'Port','2',...
		'position',[350,145,370,165])

add_block('built-in/Outport',[sys,'/',['Frequency',13,'Adaptation/out_1']])
set_param([sys,'/',['Frequency',13,'Adaptation/out_1']],...
		'position',[350,70,370,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Frequency',13,'Adaptation/freqency vector']])
set_param([sys,'/',['Frequency',13,'Adaptation/freqency vector']],...
		'MATLAB Fcn','(u(2:51))',...
		'Output Width','50',...
		'position',[255,133,310,177])
add_line([sys,'/',['Frequency',13,'Adaptation']],[205,80;250,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[230,80;230,155;250,155])
add_line([sys,'/',['Frequency',13,'Adaptation']],[125,80;145,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[45,50;65,50;65,70;85,70])
add_line([sys,'/',['Frequency',13,'Adaptation']],[315,80;345,80])
add_line([sys,'/',['Frequency',13,'Adaptation']],[45,115;65,115;65,85;85,85])
add_line([sys,'/',['Frequency',13,'Adaptation']],[315,155;345,155])
set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'Mask Display','Frequency \nAdaptation',...
		'Mask Type','Adaptation',...
		'Mask Dialogue','Adaptation Mechanism for AFA|Adaptation step-size (0.01...1):|Initial freqency (0..0.5):')
set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'Mask Translate','alpha=@1;init_freq=@2;',...
		'Mask Help','Adaptation mechanism for AFA. Input1-2: Re-ImX1, Output1: L, Output2: frequency vector.',...
		'Mask Entries','1\/1/11\/')


%     Finished composite block ['Frequency',13,'Adaptation'].

set_param([sys,'/',['Frequency',13,'Adaptation']],...
		'orientation',2,...
		'position',[255,269,320,311])

add_block('built-in/Signal Generator',[sys,'/',['NOISE',13,'generator']])
set_param([sys,'/',['NOISE',13,'generator']],...
		'Peak','0.010000',...
		'Peak Range','1.000000',...
		'Freq','0.500000',...
		'Freq Range','1.612900',...
		'Wave','Rnd',...
		'Units','Rads',...
		'position',[20,53,65,87])

add_block('built-in/Constant',[sys,'/','DC level'])
set_param([sys,'/','DC level'],...
		'Value','0.2',...
		'position',[25,200,70,220])

add_block('built-in/Note',[sys,'/','Moving Window Fourier Analysis using resonator-based FA'])
set_param([sys,'/','Moving Window Fourier Analysis using resonator-based FA'],...
		'BackGround',7,...
		'Font Name','Times New Roman',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[230,5,235,10])


%     Subsystem  ['Resonator ',13,'bank'].

new_system([sys,'/',['Resonator ',13,'bank']])
set_param([sys,'/',['Resonator ',13,'bank']],'Location',[4,42,618,417])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/FreqVector']])
set_param([sys,'/',['Resonator ',13,'bank/FreqVector']],...
		'Port','2',...
		'position',[30,130,50,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/MATLAB Fcn']])
set_param([sys,'/',['Resonator ',13,'bank/MATLAB Fcn']],...
		'MATLAB Fcn','[u(:); inf*ones(50-length(u),1)]',...
		'Output Width','50',...
		'position',[75,125,125,155])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X1)']],...
		'Port','5',...
		'position',[420,280,440,300])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X1)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X1)']],...
		'Port','4',...
		'position',[425,215,445,235])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Re(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Re(X)']],...
		'Port','2',...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/Im(X)']])
set_param([sys,'/',['Resonator ',13,'bank/Im(X)']],...
		'Port','3',...
		'position',[425,150,445,170])

add_block('built-in/Outport',[sys,'/',['Resonator ',13,'bank/output_signal_(y)']])
set_param([sys,'/',['Resonator ',13,'bank/output_signal_(y)']],...
		'position',[425,20,445,40])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Im X1']],...
		'MATLAB Fcn','u(53)',...
		'Output Width','1',...
		'position',[335,275,385,305])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re X1']])
set_param([sys,'/',['Resonator ',13,'bank/select Re X1']],...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,210,385,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Im']])
set_param([sys,'/',['Resonator ',13,'bank/select Im']],...
		'MATLAB Fcn','u(52:101)',...
		'Output Width','50',...
		'position',[335,145,385,175])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select Re']])
set_param([sys,'/',['Resonator ',13,'bank/select Re']],...
		'MATLAB Fcn','u(2:51)',...
		'Output Width','50',...
		'position',[330,80,380,110])

add_block('built-in/MATLAB Fcn',[sys,'/',['Resonator ',13,'bank/select y']])
set_param([sys,'/',['Resonator ',13,'bank/select y']],...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[330,15,380,45])

add_block('built-in/Mux',[sys,'/',['Resonator ',13,'bank/Mux']])
set_param([sys,'/',['Resonator ',13,'bank/Mux']],...
		'inputs','2',...
		'position',[160,76,190,109])

add_block('built-in/S-Function',[sys,'/',['Resonator ',13,'bank/S-function: RFA']])
set_param([sys,'/',['Resonator ',13,'bank/S-function: RFA']],...
		'function name','resonfa',...
		'parameters',' CalcR',...
		'position',[230,70,280,120])

add_block('built-in/Inport',[sys,'/',['Resonator ',13,'bank/input_signal']])
set_param([sys,'/',['Resonator ',13,'bank/input_signal']],...
		'position',[30,75,50,95])
add_line([sys,'/',['Resonator ',13,'bank']],[195,95;225,95])
add_line([sys,'/',['Resonator ',13,'bank']],[55,85;155,85])
add_line([sys,'/',['Resonator ',13,'bank']],[285,95;325,95])
add_line([sys,'/',['Resonator ',13,'bank']],[385,95;420,95])
add_line([sys,'/',['Resonator ',13,'bank']],[385,30;420,30])
add_line([sys,'/',['Resonator ',13,'bank']],[390,160;420,160])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;315,160;330,160])
add_line([sys,'/',['Resonator ',13,'bank']],[315,95;325,30])
add_line([sys,'/',['Resonator ',13,'bank']],[390,225;420,225])
add_line([sys,'/',['Resonator ',13,'bank']],[390,290;415,290])
add_line([sys,'/',['Resonator ',13,'bank']],[315,160;315,225;330,225])
add_line([sys,'/',['Resonator ',13,'bank']],[315,225;315,290;330,290])
add_line([sys,'/',['Resonator ',13,'bank']],[55,140;70,140])
add_line([sys,'/',['Resonator ',13,'bank']],[130,140;135,140;135,100;155,100])
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Display','Resonator\nBank',...
		'Mask Type','Resonator bank',...
		'Mask Dialogue','Resonator bank |Calculation method of ''r'' (''alpha/N'', 0<apha<2; or ''FIR'')')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Translate','CalcR=@1;')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Help','Resonator bank structure. Input1: e, Input2: frequency values in rad/s. Output1: y, Output2: ReX, Output3: ImX. [Output4: ReX(1), Output5: ImX(1), for convenience only]')
set_param([sys,'/',['Resonator ',13,'bank']],...
		'Mask Entries','''1/N''\/')


%     Finished composite block ['Resonator ',13,'bank'].

set_param([sys,'/',['Resonator ',13,'bank']],...
		'position',[250,116,320,194])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','-+',...
		'position',[195,117,215,153])

add_block('built-in/Note',[sys,'/',['frequency',13,'vector']])
set_param([sys,'/',['frequency',13,'vector']],...
		'position',[215,180,220,185])


%     Subsystem  'monitor: L'.

new_system([sys,'/','monitor: L'])
set_param([sys,'/','monitor: L'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','monitor: L/monitor S-fcn'])
set_param([sys,'/','monitor: L/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','monitor: L/in_1'])
set_param([sys,'/','monitor: L/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','monitor: L'],[40,90;50,90])
set_param([sys,'/','monitor: L'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','monitor: L'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','monitor: L'],...
		'Mask Entries','1\/')


%     Finished composite block 'monitor: L'.

set_param([sys,'/','monitor: L'],...
		'position',[270,234,305,256])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+++',...
		'position',[125,127,145,163])


%     Subsystem  ['Band Limited ',13,'Signal Generator'].

new_system([sys,'/',['Band Limited ',13,'Signal Generator']])
set_param([sys,'/',['Band Limited ',13,'Signal Generator']],'Location',[4,80,149,205])

add_block('built-in/S-Function',[sys,'/',['Band Limited ',13,'Signal Generator/Band Limited',13,'Signal Generator']])
set_param([sys,'/',['Band Limited ',13,'Signal Generator/Band Limited',13,'Signal Generator']],...
		'function name','blsiggen',...
		'parameters','Freq, Ampl, Phase, MaxN, Shape, sample',...
		'position',[50,59,110,81])

add_block('built-in/Outport',[sys,'/',['Band Limited ',13,'Signal Generator/out_1']])
set_param([sys,'/',['Band Limited ',13,'Signal Generator/out_1']],...
		'position',[125,60,145,80])
add_line([sys,'/',['Band Limited ',13,'Signal Generator']],[115,70;120,70])
set_param([sys,'/',['Band Limited ',13,'Signal Generator']],...
		'Mask Display',' plot([0:.2:7], sum([sin([0:.2:7]); sin([0:.6: 21])/3; sin([0:1:35 ])/5]), [-.5 7.5], [0 0 ], [0 0],[-1.1 1.1])',...
		'Mask Type','Band-limited signal generator')
set_param([sys,'/',['Band Limited ',13,'Signal Generator']],...
		'Mask Dialogue','Band Limited Signal Generator|Frequency:|Amplitude:|Initial Phase (can not be changed in run-time):|Max number of harmonics (can not be changed in run-time):|Signal Shape (Sine, Triangular, sQuare):|Sample time:')
set_param([sys,'/',['Band Limited ',13,'Signal Generator']],...
		'Mask Translate','Freq=@1; Ampl=@2; Phase=@3; MaxN=@4; Shape=@5; sample=@6;',...
		'Mask Entries','0.26\/1\/0\/15\/''s''\/1\/')


%     Finished composite block ['Band Limited ',13,'Signal Generator'].

set_param([sys,'/',['Band Limited ',13,'Signal Generator']],...
		'position',[20,126,65,164])


%     Subsystem  ['Auto-Scale',13,'Graph2'].

new_system([sys,'/',['Auto-Scale',13,'Graph2']])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Auto-Scale',13,'Graph2/x']])
set_param([sys,'/',['Auto-Scale',13,'Graph2/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Auto-Scale',13,'Graph2']],[90,65;125,65])
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):|Sample time:')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=@6;')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Help','Uses MATLAB''s graph window.\nUse only one block per system.\nLine type must be in quotes.\nSee the M-file sfunyst.m.')
set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'Mask Entries','100\/-1.1\/1.1\/100\/''r-/g-/c-/y-/w-/m-/b-''\/1\/')


%     Finished composite block ['Auto-Scale',13,'Graph2'].

set_param([sys,'/',['Auto-Scale',13,'Graph2']],...
		'position',[460,130,490,170])


%     Subsystem  ['Complex',13,'Abs'].

new_system([sys,'/',['Complex',13,'Abs']])
set_param([sys,'/',['Complex',13,'Abs']],'Location',[154,254,709,464])

add_block('built-in/Sum',[sys,'/',['Complex',13,'Abs/Sum1']])
set_param([sys,'/',['Complex',13,'Abs/Sum1']],...
		'position',[325,110,345,130])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product1']])
set_param([sys,'/',['Complex',13,'Abs/Product1']],...
		'position',[265,140,290,160])

add_block('built-in/Product',[sys,'/',['Complex',13,'Abs/Product']])
set_param([sys,'/',['Complex',13,'Abs/Product']],...
		'position',[265,85,290,105])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_1']])
set_param([sys,'/',['Complex',13,'Abs/in_1']],...
		'position',[155,80,175,100])

add_block('built-in/Inport',[sys,'/',['Complex',13,'Abs/in_2']])
set_param([sys,'/',['Complex',13,'Abs/in_2']],...
		'Port','2',...
		'position',[155,135,175,155])

add_block('built-in/Outport',[sys,'/',['Complex',13,'Abs/out_1']])
set_param([sys,'/',['Complex',13,'Abs/out_1']],...
		'position',[445,110,465,130])

add_block('built-in/MATLAB Fcn',[sys,'/',['Complex',13,'Abs/MATLAB Fcn']])
set_param([sys,'/',['Complex',13,'Abs/MATLAB Fcn']],...
		'MATLAB Fcn','sqrt',...
		'position',[370,105,420,135])
add_line([sys,'/',['Complex',13,'Abs']],[350,120;365,120])
add_line([sys,'/',['Complex',13,'Abs']],[295,150;300,150;300,125;320,125])
add_line([sys,'/',['Complex',13,'Abs']],[295,95;300,95;300,115;320,115])
add_line([sys,'/',['Complex',13,'Abs']],[180,145;260,145])
add_line([sys,'/',['Complex',13,'Abs']],[250,145;225,145;225,155;260,155])
add_line([sys,'/',['Complex',13,'Abs']],[180,90;260,90])
add_line([sys,'/',['Complex',13,'Abs']],[240,90;220,90;220,100;260,100])
add_line([sys,'/',['Complex',13,'Abs']],[425,120;440,120])
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Display','[Re, Im] \n->Abs',...
		'Mask Type','Complex Abs',...
		'Mask Dialogue','Absulute value of  a complex number')
set_param([sys,'/',['Complex',13,'Abs']],...
		'Mask Help','Converts complex input (Real and Imag components) into absulute value. ')


%     Finished composite block ['Complex',13,'Abs'].

set_param([sys,'/',['Complex',13,'Abs']],...
		'position',[385,132,440,163])


%     Subsystem  'monitor: f'.

new_system([sys,'/','monitor: f'])
set_param([sys,'/','monitor: f'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','monitor: f/monitor S-fcn'])
set_param([sys,'/','monitor: f/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','monitor: f/in_1'])
set_param([sys,'/','monitor: f/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','monitor: f'],[40,90;50,90])
set_param([sys,'/','monitor: f'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','monitor: f'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','monitor: f'],...
		'Mask Entries','10\/')


%     Finished composite block 'monitor: f'.

set_param([sys,'/','monitor: f'],...
		'position',[125,254,160,276])

add_block('built-in/Gain',[sys,'/','2pi'])
set_param([sys,'/','2pi'],...
		'Gain','2*pi',...
		'position',[90,253,110,277])

add_block('built-in/Fcn',[sys,'/','Fund harmonic'])
set_param([sys,'/','Fund harmonic'],...
		'Expr','u[2]',...
		'position',[20,250,65,280])


%     Subsystem  'Fault detection'.

new_system([sys,'/','Fault detection'])
set_param([sys,'/','Fault detection'],'Location',[45,93,927,585])

add_block('built-in/Inport',[sys,'/','Fault detection/in_freq'])
set_param([sys,'/','Fault detection/in_freq'],...
		'position',[15,65,35,85])

add_block('built-in/Gain',[sys,'/','Fault detection/2pi'])
set_param([sys,'/','Fault detection/2pi'],...
		'Gain','2*pi',...
		'position',[50,63,70,87])

add_block('built-in/Inport',[sys,'/','Fault detection/in_ampl'])
set_param([sys,'/','Fault detection/in_ampl'],...
		'Port','3',...
		'position',[15,255,35,275])


%     Subsystem  'Fault detection/OR'.

new_system([sys,'/','Fault detection/OR'])
set_param([sys,'/','Fault detection/OR'],'Location',[59,237,323,377])

add_block('built-in/Outport',[sys,'/','Fault detection/OR/out_1'])
set_param([sys,'/','Fault detection/OR/out_1'],...
		'position',[215,65,235,85])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/OR/OR'])
set_param([sys,'/','Fault detection/OR/OR'],...
		'Truth Table','[0;1;1;1]',...
		'position',[130,55,185,95])

add_block('built-in/Mux',[sys,'/','Fault detection/OR/Mux'])
set_param([sys,'/','Fault detection/OR/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Inport',[sys,'/','Fault detection/OR/in_1'])
set_param([sys,'/','Fault detection/OR/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/','Fault detection/OR/in_2'])
set_param([sys,'/','Fault detection/OR/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])
add_line([sys,'/','Fault detection/OR'],[100,75;125,75])
add_line([sys,'/','Fault detection/OR'],[40,65;60,65])
add_line([sys,'/','Fault detection/OR'],[40,80;60,80])
add_line([sys,'/','Fault detection/OR'],[190,75;210,75])
set_param([sys,'/','Fault detection/OR'],...
		'Mask Display','1',...
		'Mask Type','OR',...
		'Mask Dialogue','OR Gate',...
		'Mask Help','Calculates the logical OR of the two inputs.')


%     Finished composite block 'Fault detection/OR'.

set_param([sys,'/','Fault detection/OR'],...
		'position',[260,79,290,101])


%     Subsystem  'Fault detection/AND1'.

new_system([sys,'/','Fault detection/AND1'])
set_param([sys,'/','Fault detection/AND1'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Fault detection/AND1/in_2'])
set_param([sys,'/','Fault detection/AND1/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/','Fault detection/AND1/in_1'])
set_param([sys,'/','Fault detection/AND1/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/','Fault detection/AND1/Mux'])
set_param([sys,'/','Fault detection/AND1/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/AND1/AND'])
set_param([sys,'/','Fault detection/AND1/AND'],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Fault detection/AND1/out_1'])
set_param([sys,'/','Fault detection/AND1/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Fault detection/AND1'],[190,75;210,75])
add_line([sys,'/','Fault detection/AND1'],[40,80;60,80])
add_line([sys,'/','Fault detection/AND1'],[40,65;60,65])
add_line([sys,'/','Fault detection/AND1'],[100,75;125,75])
set_param([sys,'/','Fault detection/AND1'],...
		'Mask Display','&',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block 'Fault detection/AND1'.

set_param([sys,'/','Fault detection/AND1'],...
		'position',[530,184,560,206])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn'])
set_param([sys,'/','Fault detection/Fcn'],...
		'Expr','u[2]<0.20',...
		'position',[185,64,240,86])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn1'])
set_param([sys,'/','Fault detection/Fcn1'],...
		'Expr','u[2]>0.25',...
		'position',[185,104,240,126])

add_block('built-in/Inport',[sys,'/','Fault detection/in_error'])
set_param([sys,'/','Fault detection/in_error'],...
		'Port','2',...
		'position',[15,170,35,190])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn3'])
set_param([sys,'/','Fault detection/Fcn3'],...
		'Expr','(u[1]^2)/((2*u[3])^2)',...
		'position',[145,179,180,201])

add_block('built-in/Mux',[sys,'/','Fault detection/Mux'])
set_param([sys,'/','Fault detection/Mux'],...
		'inputs','2',...
		'position',[95,171,125,204])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn8'])
set_param([sys,'/','Fault detection/Fcn8'],...
		'Expr','u[2]',...
		'position',[130,19,165,41])


%     Subsystem  ['Fault detection/Estimated',13,'variance of f'].

new_system([sys,'/',['Fault detection/Estimated',13,'variance of f']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f']],'Location',[150,55,492,163])

add_block('built-in/Filter',[sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg2']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg2']],...
		'Numerator','[1-alpha]',...
		'Denominator','[1 -alpha]',...
		'Mask Display','Exp AVG',...
		'Mask Type','Exponential average')
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg2']],...
		'Mask Dialogue','Exponential averaging: y(k)=alpha*y(k-1)+(1-alpha)*x(k)|Enter the value of alpha:',...
		'Mask Translate','alpha=@1;')
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg2']],...
		'Mask Help','Exponentila averaging.',...
		'Mask Entries','0.95\/',...
		'position',[215,40,270,70])

add_block('built-in/Fcn',[sys,'/',['Fault detection/Estimated',13,'variance of f/Fcn7']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Fcn7']],...
		'Expr','u[1]^2',...
		'position',[160,44,195,66])

add_block('built-in/Sum',[sys,'/',['Fault detection/Estimated',13,'variance of f/Sum1']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Sum1']],...
		'inputs','-+',...
		'position',[120,37,140,73])

add_block('built-in/Filter',[sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg1']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg1']],...
		'Numerator','[1-alpha]',...
		'Denominator','[1 -alpha]',...
		'Mask Display','Exp AVG',...
		'Mask Type','Exponential average')
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg1']],...
		'Mask Dialogue','Exponential averaging: y(k)=alpha*y(k-1)+(1-alpha)*x(k)|Enter the value of alpha:',...
		'Mask Translate','alpha=@1;')
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/Exp Avg1']],...
		'Mask Help','Exponentila averaging.',...
		'Mask Entries','0.95\/',...
		'position',[45,30,100,60])

add_block('built-in/Outport',[sys,'/',['Fault detection/Estimated',13,'variance of f/out_1']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/out_1']],...
		'position',[300,45,320,65])

add_block('built-in/Inport',[sys,'/',['Fault detection/Estimated',13,'variance of f/in_1']])
set_param([sys,'/',['Fault detection/Estimated',13,'variance of f/in_1']],...
		'position',[0,35,20,55])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[200,55;210,55])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[145,55;155,55])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[105,45;115,45])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[25,45;40,45])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[275,55;295,55])
add_line([sys,'/',['Fault detection/Estimated',13,'variance of f']],[25,45;25,65;115,65])


%     Finished composite block ['Fault detection/Estimated',13,'variance of f'].

set_param([sys,'/',['Fault detection/Estimated',13,'variance of f']],...
		'position',[325,4,355,56])


%     Subsystem  'Fault detection/AND'.

new_system([sys,'/','Fault detection/AND'])
set_param([sys,'/','Fault detection/AND'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Fault detection/AND/in_2'])
set_param([sys,'/','Fault detection/AND/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/','Fault detection/AND/in_1'])
set_param([sys,'/','Fault detection/AND/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/','Fault detection/AND/Mux'])
set_param([sys,'/','Fault detection/AND/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/AND/AND'])
set_param([sys,'/','Fault detection/AND/AND'],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Fault detection/AND/out_1'])
set_param([sys,'/','Fault detection/AND/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Fault detection/AND'],[190,75;210,75])
add_line([sys,'/','Fault detection/AND'],[40,80;60,80])
add_line([sys,'/','Fault detection/AND'],[40,65;60,65])
add_line([sys,'/','Fault detection/AND'],[100,75;125,75])
set_param([sys,'/','Fault detection/AND'],...
		'Mask Display','&',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block 'Fault detection/AND'.

set_param([sys,'/','Fault detection/AND'],...
		'position',[535,84,565,106])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn4'])
set_param([sys,'/','Fault detection/Fcn4'],...
		'Expr','(u[4]/u[2])>0.15',...
		'position',[100,254,135,276])


%     Subsystem  'Fault detection/AND2'.

new_system([sys,'/','Fault detection/AND2'])
set_param([sys,'/','Fault detection/AND2'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Fault detection/AND2/in_2'])
set_param([sys,'/','Fault detection/AND2/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])

add_block('built-in/Inport',[sys,'/','Fault detection/AND2/in_1'])
set_param([sys,'/','Fault detection/AND2/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/','Fault detection/AND2/Mux'])
set_param([sys,'/','Fault detection/AND2/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/AND2/AND'])
set_param([sys,'/','Fault detection/AND2/AND'],...
		'Truth Table','[0;0;0;1]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Fault detection/AND2/out_1'])
set_param([sys,'/','Fault detection/AND2/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Fault detection/AND2'],[190,75;210,75])
add_line([sys,'/','Fault detection/AND2'],[40,80;60,80])
add_line([sys,'/','Fault detection/AND2'],[40,65;60,65])
add_line([sys,'/','Fault detection/AND2'],[100,75;125,75])
set_param([sys,'/','Fault detection/AND2'],...
		'Mask Display','&',...
		'Mask Type','AND',...
		'Mask Dialogue','AND Gate',...
		'Mask Help','Calculates the logical AND of the two inputs.')


%     Finished composite block 'Fault detection/AND2'.

set_param([sys,'/','Fault detection/AND2'],...
		'position',[530,249,560,271])

add_block('built-in/Constant',[sys,'/',['Fault detection/1',13,'']])
set_param([sys,'/',['Fault detection/1',13,'']],...
		'position',[400,125,445,145])

add_block('built-in/Scope',[sys,'/','Fault detection/Scope'])
set_param([sys,'/','Fault detection/Scope'],...
		'Vgain','0.001000',...
		'Hgain','100.000000',...
		'Vmax','0.002000',...
		'Hmax','200.000000',...
		'Window',[928,151,1130,315],...
		'position',[350,212,370,238])

add_block('built-in/Filter',[sys,'/','Fault detection/Filter'])
set_param([sys,'/','Fault detection/Filter'],...
		'Numerator','[1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]',...
		'Denominator','22',...
		'position',[200,170,265,210])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn5'])
set_param([sys,'/','Fault detection/Fcn5'],...
		'Expr','u>0.01^2',...
		'position',[305,177,360,203])

add_block('built-in/Fcn',[sys,'/',['Fault detection/Limit:',13,'Transition']])
set_param([sys,'/',['Fault detection/Limit:',13,'Transition']],...
		'Expr','u[1]<1e-6',...
		'position',[405,19,460,41])


%     Subsystem  'Fault detection/Counter'.

new_system([sys,'/','Fault detection/Counter'])
set_param([sys,'/','Fault detection/Counter'],'Location',[92,116,322,316])

add_block('built-in/Outport',[sys,'/','Fault detection/Counter/Output'])
set_param([sys,'/','Fault detection/Counter/Output'],...
		'position',[190,100,210,120])

add_block('built-in/Inport',[sys,'/','Fault detection/Counter/input'])
set_param([sys,'/','Fault detection/Counter/input'],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/','Fault detection/Counter/S-function: counter'])
set_param([sys,'/','Fault detection/Counter/S-function: counter'],...
		'function name','counter',...
		'parameters','threshold, sample',...
		'position',[85,82,140,138])
add_line([sys,'/','Fault detection/Counter'],[145,110;185,110])
add_line([sys,'/','Fault detection/Counter'],[60,110;80,110])
set_param([sys,'/','Fault detection/Counter'],...
		'Mask Display','counter',...
		'Mask Type','Counter',...
		'Mask Dialogue','Counter. Indicates the time since input >= threshold|Threshold:|Min update interval:')
set_param([sys,'/','Fault detection/Counter'],...
		'Mask Translate','threshold=@1;sample=@2;',...
		'Mask Help','Counter block.',...
		'Mask Entries','0.1\/1\/')


%     Finished composite block 'Fault detection/Counter'.

set_param([sys,'/','Fault detection/Counter'],...
		'position',[385,174,420,206])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn6'])
set_param([sys,'/','Fault detection/Fcn6'],...
		'Expr','u>200',...
		'position',[440,177,495,203])


%     Subsystem  'Fault detection/NOT'.

new_system([sys,'/','Fault detection/NOT'])
set_param([sys,'/','Fault detection/NOT'],'Location',[59,237,323,377])

add_block('built-in/Inport',[sys,'/','Fault detection/NOT/in_1'])
set_param([sys,'/','Fault detection/NOT/in_1'],...
		'position',[60,65,80,85])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/NOT/NOT'])
set_param([sys,'/','Fault detection/NOT/NOT'],...
		'Truth Table','[1;0]',...
		'position',[130,55,185,95])

add_block('built-in/Outport',[sys,'/','Fault detection/NOT/out_1'])
set_param([sys,'/','Fault detection/NOT/out_1'],...
		'position',[215,65,235,85])
add_line([sys,'/','Fault detection/NOT'],[85,75;125,75])
add_line([sys,'/','Fault detection/NOT'],[190,75;210,75])
set_param([sys,'/','Fault detection/NOT'],...
		'Mask Display','NOT',...
		'Mask Type','NOT',...
		'Mask Dialogue','NOT Gate',...
		'Mask Help','Calculates the logical NOT operation of the input.')


%     Finished composite block 'Fault detection/NOT'.

set_param([sys,'/','Fault detection/NOT'],...
		'position',[525,19,555,41])

add_block('built-in/Outport',[sys,'/','Fault detection/fault_noise'])
set_param([sys,'/','Fault detection/fault_noise'],...
		'Port','2',...
		'position',[805,180,825,200])


%     Subsystem  'Fault detection/OR1'.

new_system([sys,'/','Fault detection/OR1'])
set_param([sys,'/','Fault detection/OR1'],'Location',[59,237,323,377])

add_block('built-in/Outport',[sys,'/','Fault detection/OR1/out_1'])
set_param([sys,'/','Fault detection/OR1/out_1'],...
		'position',[215,65,235,85])

add_block('built-in/Combinatorial Logic',[sys,'/','Fault detection/OR1/OR'])
set_param([sys,'/','Fault detection/OR1/OR'],...
		'Truth Table','[0;1;1;1]',...
		'position',[130,55,185,95])

add_block('built-in/Mux',[sys,'/','Fault detection/OR1/Mux'])
set_param([sys,'/','Fault detection/OR1/Mux'],...
		'inputs','2',...
		'position',[65,55,95,90])

add_block('built-in/Inport',[sys,'/','Fault detection/OR1/in_1'])
set_param([sys,'/','Fault detection/OR1/in_1'],...
		'position',[15,55,35,75])

add_block('built-in/Inport',[sys,'/','Fault detection/OR1/in_2'])
set_param([sys,'/','Fault detection/OR1/in_2'],...
		'Port','2',...
		'position',[15,70,35,90])
add_line([sys,'/','Fault detection/OR1'],[100,75;125,75])
add_line([sys,'/','Fault detection/OR1'],[40,65;60,65])
add_line([sys,'/','Fault detection/OR1'],[40,80;60,80])
add_line([sys,'/','Fault detection/OR1'],[190,75;210,75])
set_param([sys,'/','Fault detection/OR1'],...
		'Mask Display','1',...
		'Mask Type','OR',...
		'Mask Dialogue','OR Gate',...
		'Mask Help','Calculates the logical OR of the two inputs.')


%     Finished composite block 'Fault detection/OR1'.

set_param([sys,'/','Fault detection/OR1'],...
		'position',[735,179,765,201])

add_block('built-in/Outport',[sys,'/','Fault detection/faut_freq'])
set_param([sys,'/','Fault detection/faut_freq'],...
		'position',[805,85,825,105])

add_block('built-in/Outport',[sys,'/','Fault detection/fault_distortion'])
set_param([sys,'/','Fault detection/fault_distortion'],...
		'Port','3',...
		'position',[805,250,825,270])

add_block('built-in/Outport',[sys,'/','Fault detection/Transient Phase'])
set_param([sys,'/','Fault detection/Transient Phase'],...
		'Port','4',...
		'position',[805,20,825,40])


%     Subsystem  'Fault detection/monitor:'.

new_system([sys,'/','Fault detection/monitor:'])
set_param([sys,'/','Fault detection/monitor:'],'Location',[495,129,610,294])

add_block('built-in/S-Function',[sys,'/','Fault detection/monitor:/monitor S-fcn'])
set_param([sys,'/','Fault detection/monitor:/monitor S-fcn'],...
		'function name','nummon',...
		'parameters','SampTime',...
		'position',[55,65,105,115])

add_block('built-in/Inport',[sys,'/','Fault detection/monitor:/in_1'])
set_param([sys,'/','Fault detection/monitor:/in_1'],...
		'position',[15,80,35,100])
add_line([sys,'/','Fault detection/monitor:'],[40,90;50,90])
set_param([sys,'/','Fault detection/monitor:'],...
		'Mask Display','--',...
		'Mask Type','monitor',...
		'Mask Dialogue','Numerical monitor| Min Sampling Interval (see help)',...
		'Mask Translate','SampTime=@1;')
set_param([sys,'/','Fault detection/monitor:'],...
		'Mask Help','This block displays its input value. (Note: this block can significantly slow down the simulation if the Min Sampling Interval parameter is small and the input value changes rapidly. )')
set_param([sys,'/','Fault detection/monitor:'],...
		'Mask Entries','20\/')


%     Finished composite block 'Fault detection/monitor:'.

set_param([sys,'/','Fault detection/monitor:'],...
		'position',[730,419,765,441])

add_block('built-in/Fcn',[sys,'/','Fault detection/Fcn7'])
set_param([sys,'/','Fault detection/Fcn7'],...
		'Expr','u>500',...
		'position',[660,312,715,338])


%     Subsystem  'Fault detection/Counter1'.

new_system([sys,'/','Fault detection/Counter1'])
set_param([sys,'/','Fault detection/Counter1'],'Location',[92,116,322,316])

add_block('built-in/Outport',[sys,'/','Fault detection/Counter1/Output'])
set_param([sys,'/','Fault detection/Counter1/Output'],...
		'position',[190,100,210,120])

add_block('built-in/Inport',[sys,'/','Fault detection/Counter1/input'])
set_param([sys,'/','Fault detection/Counter1/input'],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/','Fault detection/Counter1/S-function: counter'])
set_param([sys,'/','Fault detection/Counter1/S-function: counter'],...
		'function name','counter',...
		'parameters','threshold, sample',...
		'position',[85,82,140,138])
add_line([sys,'/','Fault detection/Counter1'],[145,110;185,110])
add_line([sys,'/','Fault detection/Counter1'],[60,110;80,110])
set_param([sys,'/','Fault detection/Counter1'],...
		'Mask Display','counter',...
		'Mask Type','Counter',...
		'Mask Dialogue','Counter. Indicates the time since input >= threshold|Threshold:|Min update interval:')
set_param([sys,'/','Fault detection/Counter1'],...
		'Mask Translate','threshold=@1;sample=@2;',...
		'Mask Help','Counter block.',...
		'Mask Entries','0.01\/1\/')


%     Finished composite block 'Fault detection/Counter1'.

set_param([sys,'/','Fault detection/Counter1'],...
		'position',[605,309,640,341])

add_block('built-in/Filter',[sys,'/','Fault detection/Filter1'])
set_param([sys,'/','Fault detection/Filter1'],...
		'Numerator','[1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]',...
		'Denominator','20',...
		'position',[540,304,585,346])
add_line([sys,'/','Fault detection'],[270,190;300,190])
add_line([sys,'/','Fault detection'],[185,190;195,190])
add_line([sys,'/','Fault detection'],[295,90;530,90])
add_line([sys,'/','Fault detection'],[245,115;255,95])
add_line([sys,'/','Fault detection'],[245,75;255,85])
add_line([sys,'/','Fault detection'],[570,95;800,95])
add_line([sys,'/','Fault detection'],[40,75;45,75])
add_line([sys,'/','Fault detection'],[75,75;180,75])
add_line([sys,'/','Fault detection'],[75,75;75,115;180,115])
add_line([sys,'/','Fault detection'],[40,180;90,180])
add_line([sys,'/','Fault detection'],[40,265;55,265;90,195])
add_line([sys,'/','Fault detection'],[130,190;140,190])
add_line([sys,'/','Fault detection'],[50,265;95,265])
add_line([sys,'/','Fault detection'],[360,30;400,30])
add_line([sys,'/','Fault detection'],[170,30;320,30])
add_line([sys,'/','Fault detection'],[112,75;112,30;125,30])
add_line([sys,'/','Fault detection'],[560,30;800,30])
add_line([sys,'/','Fault detection'],[465,30;520,30])
add_line([sys,'/','Fault detection'],[565,260;800,260])
add_line([sys,'/','Fault detection'],[140,265;525,265])
add_line([sys,'/','Fault detection'],[280,190;275,190;275,225;345,225])
add_line([sys,'/','Fault detection'],[365,190;380,190])
add_line([sys,'/','Fault detection'],[425,190;435,190])
add_line([sys,'/','Fault detection'],[500,190;525,190])
add_line([sys,'/','Fault detection'],[645,325;655,325])
add_line([sys,'/','Fault detection'],[720,325;730,185])
add_line([sys,'/','Fault detection'],[565,195;730,195])
add_line([sys,'/','Fault detection'],[770,190;800,190])
add_line([sys,'/','Fault detection'],[505,30;505,255;525,255])
add_line([sys,'/','Fault detection'],[505,100;530,100])
add_line([sys,'/','Fault detection'],[505,200;525,200])
add_line([sys,'/','Fault detection'],[645,325;630,430;725,430])
add_line([sys,'/','Fault detection'],[590,325;600,325])
add_line([sys,'/','Fault detection'],[650,30;650,297;505,297;505,325;535,325])


%     Finished composite block 'Fault detection'.

set_param([sys,'/','Fault detection'],...
		'position',[470,324,500,381])


%     Subsystem  ['LED1:',13,'Fault: Bad frequency'].

new_system([sys,'/',['LED1:',13,'Fault: Bad frequency']])
set_param([sys,'/',['LED1:',13,'Fault: Bad frequency']],'Location',[92,116,322,316])

add_block('built-in/Inport',[sys,'/',['LED1:',13,'Fault: Bad frequency/in_1']])
set_param([sys,'/',['LED1:',13,'Fault: Bad frequency/in_1']],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/',['LED1:',13,'Fault: Bad frequency/S-function: led']])
set_param([sys,'/',['LED1:',13,'Fault: Bad frequency/S-function: led']],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])
add_line([sys,'/',['LED1:',13,'Fault: Bad frequency']],[60,110;80,110])
set_param([sys,'/',['LED1:',13,'Fault: Bad frequency']],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:')
set_param([sys,'/',['LED1:',13,'Fault: Bad frequency']],...
		'Mask Translate','COLOR=@1;sample=@2;',...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[7 1 6]\/1\/')


%     Finished composite block ['LED1:',13,'Fault: Bad frequency'].

set_param([sys,'/',['LED1:',13,'Fault: Bad frequency']],...
		'position',[570,190,590,200])


%     Subsystem  ['LED2:',13,'Fault: Noisy Input'].

new_system([sys,'/',['LED2:',13,'Fault: Noisy Input']])
set_param([sys,'/',['LED2:',13,'Fault: Noisy Input']],'Location',[92,116,322,316])

add_block('built-in/Inport',[sys,'/',['LED2:',13,'Fault: Noisy Input/in_1']])
set_param([sys,'/',['LED2:',13,'Fault: Noisy Input/in_1']],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/',['LED2:',13,'Fault: Noisy Input/S-function: led']])
set_param([sys,'/',['LED2:',13,'Fault: Noisy Input/S-function: led']],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])
add_line([sys,'/',['LED2:',13,'Fault: Noisy Input']],[60,110;80,110])
set_param([sys,'/',['LED2:',13,'Fault: Noisy Input']],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:')
set_param([sys,'/',['LED2:',13,'Fault: Noisy Input']],...
		'Mask Translate','COLOR=@1;sample=@2;',...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[7 1 6]\/1\/')


%     Finished composite block ['LED2:',13,'Fault: Noisy Input'].

set_param([sys,'/',['LED2:',13,'Fault: Noisy Input']],...
		'position',[570,255,590,265])


%     Subsystem  ['LED3:',13,'Fault: Distorted Input'].

new_system([sys,'/',['LED3:',13,'Fault: Distorted Input']])
set_param([sys,'/',['LED3:',13,'Fault: Distorted Input']],'Location',[92,116,322,316])

add_block('built-in/Inport',[sys,'/',['LED3:',13,'Fault: Distorted Input/in_1']])
set_param([sys,'/',['LED3:',13,'Fault: Distorted Input/in_1']],...
		'position',[35,100,55,120])

add_block('built-in/S-Function',[sys,'/',['LED3:',13,'Fault: Distorted Input/S-function: led']])
set_param([sys,'/',['LED3:',13,'Fault: Distorted Input/S-function: led']],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])
add_line([sys,'/',['LED3:',13,'Fault: Distorted Input']],[60,110;80,110])
set_param([sys,'/',['LED3:',13,'Fault: Distorted Input']],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:')
set_param([sys,'/',['LED3:',13,'Fault: Distorted Input']],...
		'Mask Translate','COLOR=@1;sample=@2;',...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[7 1 6]\/1\/')


%     Finished composite block ['LED3:',13,'Fault: Distorted Input'].

set_param([sys,'/',['LED3:',13,'Fault: Distorted Input']],...
		'position',[580,305,600,315])


%     Subsystem  ['LED4:',13,'Not Ready'].

new_system([sys,'/',['LED4:',13,'Not Ready']])
set_param([sys,'/',['LED4:',13,'Not Ready']],'Location',[92,116,322,316])

add_block('built-in/S-Function',[sys,'/',['LED4:',13,'Not Ready/S-function: led']])
set_param([sys,'/',['LED4:',13,'Not Ready/S-function: led']],...
		'function name','led',...
		'parameters','COLOR, sample',...
		'position',[85,82,140,138])

add_block('built-in/Inport',[sys,'/',['LED4:',13,'Not Ready/in_1']])
set_param([sys,'/',['LED4:',13,'Not Ready/in_1']],...
		'position',[35,100,55,120])
add_line([sys,'/',['LED4:',13,'Not Ready']],[60,110;80,110])
set_param([sys,'/',['LED4:',13,'Not Ready']],...
		'Mask Display','plot(1,1)',...
		'Mask Type','LED',...
		'Mask Dialogue','''LED'' indicator|Enter desired color code for -, 0, and + input:|Min. update interval:')
set_param([sys,'/',['LED4:',13,'Not Ready']],...
		'Mask Translate','COLOR=@1;sample=@2;',...
		'Mask Help','''LED'' indicator box. The color of the box depends on the input value. ',...
		'Mask Entries','[7 3 6]\/1\/')


%     Finished composite block ['LED4:',13,'Not Ready'].

set_param([sys,'/',['LED4:',13,'Not Ready']],...
		'position',[580,360,600,370])
add_line(sys,[70,70;100,70;100,135;120,135])
add_line(sys,[75,210;100,210;100,155;120,155])
add_line(sys,[445,150;455,150])
add_line(sys,[150,145;150,60;235,60])
add_line(sys,[325,140;380,140])
add_line(sys,[325,155;380,155])
add_line(sys,[250,300;175,300;175,175;245,175])
add_line(sys,[325,170;345,170;345,280;325,280])
add_line(sys,[325,185;340,185;340,300;325,300])
add_line(sys,[325,125;340,125;340,105;175,105;175,125;190,125])
add_line(sys,[150,145;190,145])
add_line(sys,[335,105;335,65;385,65])
add_line(sys,[250,280;235,280;235,245;265,245])
add_line(sys,[70,265;85,265])
add_line(sys,[115,265;120,265])
add_line(sys,[175,300;5,300;15,265])
add_line(sys,[220,135;245,135])
add_line(sys,[70,145;120,145])
add_line(sys,[220,135;230,135;230,355;465,355])
add_line(sys,[505,330;565,195])
add_line(sys,[505,345;565,260])
add_line(sys,[170,300;170,335;465,335])
add_line(sys,[445,150;450,150;450,375;465,375])
add_line(sys,[505,375;525,375;525,365;575,365])
add_line(sys,[505,360;540,360;540,310;575,310])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
