function [sys, x0] = trplot(t,x,u,flag,ax, N)

% function [sys, x0] = trplot(t,x,u,flag,ax, N)
% S-function: 2D trace plot for discrete signals (Comet-scope).
% The last N samples of the signal are plotted in the x-y 
% coordinate system, the axis is defined by ax.
% t, x, u, flag are conventional S-function parameters.

% (c) Gy. Simon, 28-07-1997

sample=1;

if  abs(flag)==2
	sample_hit = (rem(t+sample/1e8,sample) < sample/1e6);
	if sample_hit 
	    f=x(1);
	    if f==0 % first time; create figure if necessary

		[c_system,c_block] = get_param;
		f=findobj('tag', c_system);
		if isempty(f)
			f=figure('position', [100 200 350 280], ...
			 'name', c_system, ...
			 'numbertitle', 'off',...
			 'tag', c_system);
		end
		figure(f), clf
		set(f, 'nextplot', 'add')
		set(gca, 'box', 'on', 'nextplot', 'add')
		grid on, drawnow
		line_tail=plot(0, 0, 'w.');
		line_head=plot(0, 0, 'r*');
		set(gca, 'box', 'on', 'nextplot', 'new')
	
		set(line_tail, 'xdata', [], 'ydata', [], ...
			'erasemode', 'bac');
		set(line_head, 'xdata', [], 'ydata', [], ...
			'erasemode', 'bac');
	
		store=NaN*ones(1,N);
	
		set(f, 'userdata', store, 'nextplot', 'new');

		x =[f line_head line_tail];		% state var contains window handle
	    end	
	    % add new point
		%check axis settings
		line_head=x(2);
		line_tail=x(3);

		myaxes=get(line_head, 'parent');
% MATLAB BUG: the following code does not work properly on PC: the figure 
% may not be refreshed after a while... ???????
% The bug may occur even without this code, depending eg. on the
% size of the figure.
%		if ~floor(rem(t,5)),   % update grid
%			set(myaxes, 'xgrid', 'on', 'ygrid', 'on');
%		end
		set(myaxes, 'xlim', ax(1:2), 'ylim', ax(3:4));
		store=get(f,'userdata');
		N_old=length(store);
		if N_old > N
			store=store(N_old-N+1:N_old);
		elseif N_old < N
			store=[NaN*ones(1, N-N_old), store];
		end
		store=[store(2:N) u(1)+j*u(2)];
		set(f,'userdata',store);
	
		%set new head
		set(line_head, ...
			'xdata', real(store(N)), ...
			'ydata', imag(store(N)));

		%set new tail
		set(line_tail, ...
			'xdata', real(store(1:N)), ...
			'ydata', imag(store(1:N)));
	
		sys=x;	    
	else
		sys = x;
	end
elseif flag == 3
	sys=[];

elseif flag ==4, 
	sys=ceil(t/sample+sample/1e8)*sample;

elseif flag == 0,


	sys(1) = 0;	% 0 continuous states
	sys(2) = 3;	% 3 discrete states
	sys(3) = 0;	% 0 outputs
	sys(4) = 2;	% 2 inputs
	sys(5) = 0;	% 0 roots
	sys(6) = 0;	% no direct feedthrough
%	sys(7) = 1;	% 1 sample time

	x0 =[0 0 0];		% state var later contains handles

end

